#
# spec file for package helmfile
#
# Copyright (c) 2025 SUSE LLC
#               2021-2025 Manfred Hollstein <manfred.h@gmx.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_commit e6f88adb50594b92ca8c7cee30a4944d24647208
Name:           helmfile
Version:        1.1.3
Release:        1.1
Summary:        Deploy Kubernetes Helm Charts
License:        MIT
Group:          Development/Languages/Other
URL:            https://github.com/helmfile/helmfile
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Requires:       helm >= 3.13.1
Recommends:     helm >= 3.14.3
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.24
Obsoletes:      %{name}-bash-completion < %{version}
Obsoletes:      %{name}-zsh-completion < %{version}

%description
Helmfile is a declarative spec for deploying helm charts. It lets you...

 * Keep a directory of chart value files and maintain changes in version control.
 * Apply CI/CD to configuration changes.
 * Periodically sync to avoid skew in environments.

To avoid upgrades for each iteration of helm, the helmfile executable
delegates to helm - as a result, helm must be installed.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -qa1

%build
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
SOURCE_DATE_EPOCH=$(date -u -d "${modified}" "+%s")
export SOURCE_DATE_EPOCH
rm -f source_date_epoch
echo SOURCE_DATE_EPOCH=$SOURCE_DATE_EPOCH > source_date_epoch
go build -mod=vendor -buildmode=pie

%install
. ./source_date_epoch
export SOURCE_DATE_EPOCH
make TAG=v%{version} install
mkdir -p %{buildroot}%{_bindir}
install -m755 ${HOME}/go/bin/helmfile %{buildroot}/%{_bindir}/helmfile
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/helmfile completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/helmfile completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/helmfile completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/helmfile

%files bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%files fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Fri Jul 11 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.3:
  What's Changed
  * build: update Helm to v3.18.3 and related dependencies by
    @yxxhero in #2082
  * Expose release version as .Release.ChartVersion for templating
    by @Simske in #2080
  * build(deps): bump github.com/helmfile/chartify from 0.24.3 to
    0.24.4 by @dependabot[bot] in #2083
  * build(deps): bump k8s.io/apimachinery from 0.33.1 to 0.33.2
    by @dependabot[bot] in #2086
  * build(deps): bump github.com/helmfile/chartify from 0.24.4 to
    0.24.5 by @dependabot[bot] in #2087
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.3.1
    to 3.4.0 by @dependabot[bot] in #2089
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.23.0 to
    2.24.0 by @dependabot[bot] in #2092
  * build: update Helm and plugin versions to v3.18.4 and v3.12.3
    by @yxxhero in #2093
  * docs: update status section with May 2025 release information
    by @yxxhero in #2096
  * build(deps): bump golang.org/x/sync from 0.15.0 to 0.16.0 by
    @dependabot[bot] in #2099
  * build(deps): bump golang.org/x/term from 0.32.0 to 0.33.0 by
    @dependabot[bot] in #2098
* Fri Jun 13 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.2:
  What's Changed
  * build(deps): bump github.com/helmfile/chartify from 0.24.2 to
    0.24.3 by @dependabot in #2065
  * build: update Helm to v3.18.2 and adjust related configurations
    by @yxxhero in #2064
  * build(deps): bump github.com/helmfile/vals from 0.41.1 to
    0.41.2 by @dependabot in #2067
  * build(deps): bump golang.org/x/sync from 0.14.0 to 0.15.0
    by @dependabot in #2068
  * fix-insecure-flag by @anontrex in #2072
  * build(deps): bump github.com/cloudflare/circl from 1.4.0 to
    1.6.1 by @dependabot in #2074
  * fix: update helm-diff to version 3.12.2 in CI and Dockerfiles
    by @yxxhero in #2073
  * fix: TestToYaml not working with 32-bit architectures by
    @ProbstDJakob in #2075
* Sat May 31 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.1:
  What's Changed
  * Update README.md by @mumoshu in #2046
  * build(deps): bump github.com/helmfile/vals from 0.41.0 to
    0.41.1 by @dependabot in #2048
  * build(helm) update to v3.18.0 by @yxxhero in #2044
  * build(deps): bump github.com/helmfile/chartify from 0.23.0 to
    0.24.1 by @dependabot in #2049
  * build: update Helm and plugin versions in CI and Dockerfiles
    by @yxxhero in #2059
* Tue May 20 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.0:
  What's Changed
  * chore: fix typo in create_test.go by @sadikkuzu in #2025
  * build(deps): bump golangci/golangci-lint-action from 7 to 8 by
    @dependabot in #2029
  * build(deps): bump golang.org/x/sync from 0.13.0 to 0.14.0 by
    @dependabot in #2028
  * build(deps): bump github.com/helmfile/chartify from 0.22.0 to
    0.23.0 by @dependabot in #2027
  * chore: remove test data files by @yxxhero in #2026
  * build(deps): bump golang.org/x/term from 0.31.0 to 0.32.0 by
    @dependabot in #2033
  * build(deps): bump github.com/helmfile/vals from 0.40.1 to
    0.41.0 by @dependabot in #2032
  * build(deps): bump dario.cat/mergo from 1.0.1 to 1.0.2 by
    @dependabot in #2035
  * feat(tmpl): enhance ToYaml test with multiple scenarios by
    @yxxhero in #2031
  * [sops, age] update to have SSH key support with sops by
    @itscaro in #2036
  * feat(yaml): add JSON style encoding option to NewEncoder by
    @yxxhero in #2038
  * refactor(yaml): upgrade from gopkg.in/yaml.v2 to v3 by @yxxhero
    in #2039
  * Update readme & documentation with 2025 status of helmfile
    project by @zhaque44 in #2040
  * build(deps): bump k8s.io/apimachinery from 0.33.0 to 0.33.1 by
    @dependabot in #2041
  * build(deps): bump github.com/zclconf/go-cty from 1.16.2 to
    1.16.3 by @dependabot in #2043
* Wed Apr 30 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.0.0:
  PLEASE READ
  https://github.com/helmfile/helmfile/blob/main/docs/proposals/towards-1.0.md
  What's Changed:
  * build(deps): bump github.com/helmfile/vals from 0.39.0 to 0.39.1
    by @dependabot in #1926
  * Bump kubectl to current version (1.32.1) by @DerDaku in #1924
  * build(deps): bump github.com/goccy/go-yaml from 1.15.21 to 1.15.22
    by @dependabot in #1925
  * build: update Helm to v3.17.1 and related dependencies by
    @yxxhero in #1928
  * build(deps): bump k8s.io/apimachinery from 0.32.1 to 0.32.2 by
    @dependabot in #1931
  * feat: inject cli state values (--state-values-set) into environment
    templating context by @Vince-Chenal in #1917
  * docs: add skipSchemaValidation to index.md and update related
    structs by @yxxhero in #1935
  * refactor(state): optimize HelmState flags handling by @yxxhero
    in #1937
  * Update vals package to v0.39.2 by @aditmeno in #1938
  * build(deps): bump github.com/spf13/cobra from 1.8.1 to 1.9.1 by
    @dependabot in #1940
  * build(deps): bump github.com/goccy/go-yaml from 1.15.22 to 1.15.23
    by @dependabot in #1941
  * build(deps): bump github.com/helmfile/chartify from 0.20.8 to
    0.20.9 by @dependabot in #1942
  * feat: colorized DELETED by @yurrriq in #1944
  * feat(docs): add proposal to remove charts and delete subcommands
    by @yxxhero in #1936
  * build(deps): bump github.com/google/go-cmp from 0.6.0 to 0.7.0
    by @dependabot in #1945
  * build(deps): bump github.com/go-jose/go-jose/v4 from 4.0.4 to
    4.0.5 by @dependabot in #1946
  * build: update golang version to 1.24 and golangci-lint to
    v1.64.5 by @yxxhero in #1949
  * build(deps): bump github.com/helmfile/vals from 0.39.2 to 0.39.3
    by @dependabot in #1951
  * build(deps): bump github.com/helmfile/chartify from 0.20.9 to
    0.21.0 by @dependabot in #1950
  * build(deps): bump golang.org/x/sync from 0.11.0 to 0.12.0 by
    @dependabot in #1955
  * build(deps): bump jinja2 from 3.1.5 to 3.1.6 in /docs by
    @dependabot in #1956
  * Don't warn if this and the needed release set installed: false
    by @jayme-github in #1958
  * build(deps): bump golang.org/x/term from 0.29.0 to 0.30.0 by
    @dependabot in #1959
  * Remove all v0.x references by @yxxhero in #1919
  * build(deps): bump k8s.io/apimachinery from 0.32.2 to 0.32.3
    by @dependabot in #1960
  * build(deps): bump golang.org/x/net from 0.35.0 to 0.36.0 by
    @dependabot in #1961
  * build(deps): bump github.com/helmfile/vals from 0.39.3 to 0.39.4
    by @dependabot in #1962
  * build: update Helm to v3.17.2 and related dependencies by
    @yxxhero in #1965
  * build: update yaml.v3 dependency and remove colega/go-yaml-yaml
    by @yxxhero in #1929
  * build(deps): bump github.com/containerd/containerd from 1.7.24
    to 1.7.27 by @dependabot in #1966
  * build(deps): bump github.com/goccy/go-yaml from 1.15.23 to
    1.16.0 by @dependabot in #1967
  * build(deps): bump github.com/golang-jwt/jwt/v5 from 5.2.1 to
    5.2.2 by @dependabot in #1969
  * build(deps): bump github.com/golang-jwt/jwt/v4 from 4.5.1 to
    4.5.2 by @dependabot in #1970
  * build(deps): bump golangci/golangci-lint-action from 6 to 7
    by @dependabot in #1975
  * build(deps): bump github.com/helmfile/vals from 0.39.4 to
    0.40.0 by @dependabot in #1978
  * build(deps): bump github.com/helmfile/chartify from 0.21.0 to
    0.21.1 by @dependabot in #1979
  * docs(fix): correct typo in 'tier=fronted' to 'tier=frontend'
    by @yxxhero in #1980
  * feat: add labels for helm release by @yxxhero in #1046
  * build(deps): bump github.com/helmfile/vals from 0.40.0 to
    0.40.1 by @dependabot in #1981
  * build(deps): bump github.com/goccy/go-yaml from 1.16.0 to 1.17.1
    by @dependabot in #1982
  * fix: Check needs with context and namespace by @aarnq in #1986
  * build(deps): bump golang.org/x/sync from 0.12.0 to 0.13.0 by
    @dependabot in #1991
  * build(deps): bump golang.org/x/term from 0.30.0 to 0.31.0 by
    @dependabot in #1990
  * fix(state): enhance error message for missing .gotmpl extension
    in helmfile v1 by @yxxhero in #1989
  * build(deps): bump github.com/helmfile/chartify from 0.21.1 to
    0.22.0 by @dependabot in #1996
  * build: update Helm plugin versions in CI and Dockerfiles by
    @yxxhero in #1995
  * build: update Helm to v3.17.3 and update related Dockerfiles
    by @yxxhero in #1993
  * build(deps): bump golang.org/x/net from 0.37.0 to 0.38.0 by
    @dependabot in #2010
  * feat: add helmfile archive configuration in goreleaser by
    @yxxhero in #2000
  * docs: add more complex examples section in README by @yxxhero
    in #2013
  * Feat: setting reuseValues flag in release by @blaskoa in #2004
  * build(deps): bump k8s.io/apimachinery from 0.32.3 to 0.32.4 by
    @dependabot in #2016
  * build(deps): bump github.com/aws/aws-sdk-go from 1.55.6 to
    1.55.7 by @dependabot in #2015
  * chore: support parsing any type with fromYaml by @ProbstDJakob
    in #2017
  * build(deps): bump k8s.io/apimachinery from 0.32.4 to 0.33.0 by
    @dependabot in #2018
  * feat: add --take-ownership flag to helm diff and related config
    by @yxxhero in #1992
* Thu Feb 13 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.171.0:
  * feat: execute templates against postRendererHooks by @allanger
    in #1839
  * build(deps): bump github.com/spf13/pflag from 1.0.5 to 1.0.6
    by @dependabot in #1897
  * build(deps): bump github.com/goccy/go-yaml from 1.15.15 to
    1.15.16 by @dependabot in #1901
  * build(deps): bump github.com/goccy/go-yaml from 1.15.16 to
    1.15.17 by @dependabot in #1905
  * Use a regex to match --state-values-set-string arguments
    by @gllb in #1902
  * build(deps): bump golang.org/x/sync from 0.10.0 to 0.11.0
    by @dependabot in #1911
  * Chartify v0.20.8 update by @scodeman in #1908
  * cleanup: remove all about v0.x by @yxxhero in #1903
  * build(deps): bump golang.org/x/term from 0.28.0 to 0.29.0
    by @dependabot in #1913
  * chore: update babel to resolve CVEs by @zhaque44 in #1916
  * remove deprecated charts.yaml by @yxxhero in #1437
  * Revert "cleanup: remove all about v0.x" by @yxxhero in #1918
  * build(deps): bump github.com/goccy/go-yaml from 1.15.17 to
    1.15.19 by @dependabot in #1920
  * build(deps): bump github.com/goccy/go-yaml from 1.15.19 to
    1.15.20 by @dependabot in #1921
  * feat: Add support for --wait-retries flag. by @connyay in #1922
  * build: update go-yaml to v1.15.21 by @yxxhero in #1923
* Thu Jan 23 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.170.1:
  * build(deps): bump github.com/goccy/go-yaml from 1.15.14 to
    1.15.15 by @dependabot in #1882
  * build(deps): bump github.com/hashicorp/go-slug from 0.15.0 to
    0.16.3 by @dependabot in #1886 (CVE-2025-0377)
  * Ensure 'helm repo add' is also not pollute on helmfile template
    by @baurmatt in #1887
  * build(deps): bump github.com/zclconf/go-cty from 1.16.1 to
    1.16.2 by @dependabot in #1888
  * fix: using correct option for takeOwnership flag by @blaskoa
    in #1892
  * fix typo in docs by @adamab48 in #1889
* Tue Jan 21 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.170.0:
  * build(deps): bump github.com/goccy/go-yaml from 1.15.6 to 1.15.7
    by @dependabot in #1818
  * build(deps): bump golang.org/x/term from 0.26.0 to 0.27.0 by
    @dependabot in #1817
  * chore(doc): fix the indent of the selector usage sample yaml by
    @Ladicle in #1819
  * feat(state): add support for setString in ReleaseSpec and
    HelmState by @yxxhero in #1821
  * build(deps): bump github.com/goccy/go-yaml from 1.15.7 to 1.15.8
    by @dependabot in #1822
  * test(state): add TestHelmState_setStringFlags for setStringFlags
    method by @yxxhero in #1823
  * build(deps): bump k8s.io/apimachinery from 0.31.3 to 0.31.4 by
    @dependabot in #1826
  * build(deps): bump golang.org/x/crypto from 0.29.0 to 0.31.0 by
    @dependabot in #1828
  * build(deps): bump github.com/goccy/go-yaml from 1.15.8 to
    1.15.9 by @dependabot in #1831
  * build(deps): bump k8s.io/apimachinery from 0.31.4 to 0.32.0 by
    @dependabot in #1830
  * feat: updating sops version to 3.9.2 by @zhaque44 in #1834
  * build(deps): bump github.com/goccy/go-yaml from 1.15.9 to
    1.15.10 by @dependabot in #1835
  * build(deps): bump helm.sh/helm/v3 from 3.16.3 to 3.16.4 by
    @dependabot in #1836
  * build: update Helm version to v3.16.4 in CI and Dockerfiles by
    @yxxhero in #1837
  * build(deps): bump github.com/goccy/go-yaml from 1.15.10 to
    1.15.11 by @dependabot in #1838
  * build(deps): bump filippo.io/age from 1.2.0 to 1.2.1 by
    @dependabot in #1840
  * build(deps): bump github.com/goccy/go-yaml from 1.15.11 to
    1.15.12 by @dependabot in #1843
  * build: update helm-diff to v3.9.13 in Dockerfiles and init.go
    by @yxxhero in #1841
  * build(deps): bump github.com/helmfile/chartify from 0.20.4 to
    0.20.5 by @dependabot in #1845
  * build(deps): bump github.com/goccy/go-yaml from 1.15.12 to
    1.15.13 by @dependabot in #1844
  * build(deps): bump jinja2 from 3.1.4 to 3.1.5 in /docs by
    @dependabot in #1846
  * CVE-2024-45338: updating golang.org/x/net: to version: v0.33.0
    by @zhaque44 in #1849
  * build(deps): bump github.com/zclconf/go-cty from 1.15.1 to
    1.16.0 by @dependabot in #1851
  * build(deps): bump golang.org/x/term from 0.27.0 to 0.28.0
    by @dependabot in #1852
  * update sops versions to 3.9.3 by @zhaque44 in #1861
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.6
    to 1.7.7 by @dependabot in #1862
  * feat: add --take-ownership flag to apply and sync commands by
    @yxxhero in #1863
  * fix: ensure plain http is supported across all helmfile
    commands by @purpleclay in #1858
  * fix: ensure development versions of charts can be used across
    helmfile commands by @purpleclay in #1865
  * build(deps): bump github.com/helmfile/chartify from 0.20.5 to
    0.20.6 by @dependabot in #1866
  * update kubectl version (1.30) to stay up to date with new
    releases by @zhaque44 in #1867
  * build(deps): bump github.com/zclconf/go-cty from 1.16.0 to
    1.16.1 by @dependabot in #1870
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.7 to
    1.7.8 by @dependabot in #1869
  * feat: Add "--no-hooks" to helmfile template by @jwlai in #1813
  * update helm and k8s versions in ci, dockerfiles, and go.mod by
    @yxxhero in #1872
  * build(deps): bump github.com/helmfile/vals from 0.38.0 to 0.39.0
    by @dependabot in #1876
  * build(deps): bump k8s.io/apimachinery from 0.32.0 to 0.32.1 by
    @dependabot in #1873
  * build(deps): bump github.com/goccy/go-yaml from 1.15.13 to
    1.15.14 by @dependabot in #1874
  * build: update helm-diff to v3.9.14 in Dockerfiles and init.go
    by @yxxhero in #1877
* Fri Dec  6 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.169.2:
  * build(deps): bump github.com/helmfile/vals from 0.37.6 to 0.37.7
    by @dependabot in #1747
  * build(deps): bump k8s.io/apimachinery from 0.31.1 to 0.31.2 by
    @dependabot in #1754
  * Reset extra args before running 'dependency build' by @baurmatt
    in #1751
  * Introducing Helmfile Guru on Gurubase.io by @kursataktas in #1748
  * feat: add skip json schema validation during the install /upgrade
    of a Chart by @zhaque44 in #1737
  * fix(maputil): prevent nil value overwrite by @ban11111 in #1755
  * build(deps): bump github.com/goccy/go-yaml from 1.12.0 to
    1.13.0 by @dependabot in #1759
  * fix: this url doesn't work anymore by @zekena2 in #1760
  * build(deps): bump github.com/goccy/go-yaml from 1.13.0 to
    1.13.1 by @dependabot in #1762
  * build(deps): bump github.com/goccy/go-yaml from 1.13.1 to
    1.13.2 by @dependabot in #1763
  * build(deps): bump github.com/golang-jwt/jwt/v4 from 4.5.0 to
    4.5.1 by @dependabot in #1767
  * build(deps): bump github.com/helmfile/vals from 0.37.7 to
    0.37.8 by @dependabot in #1764
  * build(deps): bump github.com/goccy/go-yaml from 1.13.2 to
    1.13.4 by @dependabot in #1765
  * fix(integration-tests): read correct minikube status (#1768)
    by @ceriath in #1769
  * build(deps): bump github.com/goccy/go-yaml from 1.13.4 to
    1.13.5 by @dependabot in #1770
  * Add integration tests for #1749 by @baurmatt in #1766
  * fix: update acme chart URL in input.yaml by @yxxhero in #1773
  * build(deps): bump github.com/goccy/go-yaml from 1.13.5 to
    1.13.6 by @dependabot in #1771
  * build(deps): bump golang.org/x/sync from 0.8.0 to 0.9.0 by
    @dependabot in #1775
  * build(deps): bump golang.org/x/term from 0.25.0 to 0.26.0
    by @dependabot in #1774
  * Revive dead badge links by @eggplants in #1776
  * feat: refactor label creation in state.go by @yxxhero in #1758
  * docs: Add Gurubase badge to README-zh_CN by @yxxhero in #1777
  * build(deps): bump github.com/goccy/go-yaml from 1.13.6 to
    1.13.9 by @dependabot in #1781
  * build(deps): bump github.com/goccy/go-yaml from 1.13.9 to
    1.14.0 by @dependabot in #1782
  * build(deps): bump github.com/goccy/go-yaml from 1.14.0 to
    1.14.3 by @dependabot in #1788
  * build(deps): bump helm.sh/helm/v3 from 3.16.2 to 3.16.3 by
    @dependabot in #1786
  * fix: update helm-diff to version 3.9.12 in CI and Dockerfiles
    by @yxxhero in #1792
  * build: update Helm version to v3.16.3 in CI and Dockerfiles
    by @yxxhero in #1791
  * feat: add HELMFILE_INTERACTIVE env var to enable interactive
    mode by @thevops in #1787
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.22.0 to
    2.23.0 by @dependabot in #1793
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.3.0
    to 3.3.1 by @dependabot in #1795
  * chore: update with testify/assert assertion and table driven
    tests for fs.go by @zhaque44 in #1794
  * build(deps): bump k8s.io/apimachinery from 0.31.2 to 0.31.3
    by @dependabot in #1798
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 by @dependabot in #1800
  * build(deps): bump github.com/goccy/go-yaml from 1.14.3 to
    1.15.0 by @dependabot in #1804
  * build(deps): bump github.com/goccy/go-yaml from 1.15.0 to
    1.15.1 by @dependabot in #1807
  * build(deps): bump github.com/zclconf/go-cty from 1.15.0 to
    1.15.1 by @dependabot in #1806
  * update example chart URL in remote-secrets doc by @daveneeley
    in #1809
  * build(deps): bump github.com/goccy/go-yaml from 1.15.1 to
    1.15.3 by @dependabot in #1811
  * build(deps): bump github.com/goccy/go-yaml from 1.15.3 to
    1.15.6 by @dependabot in #1812
  * fix: inject global values in Chartify by @xabufr in #1805
  * build(deps): bump github.com/helmfile/vals from 0.37.8 to
    0.38.0 by @dependabot in #1814
  * build(deps): bump github.com/helmfile/chartify from 0.20.3 to
    0.20.4 by @dependabot in #1815
  * build(deps): bump golang.org/x/sync from 0.9.0 to 0.10.0 by
    @dependabot in #1816
* Tue Oct 22 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.169.1:
  * feat: update sops version to 3.9.1 by @zhaque44 in #1742
  * chore: improve test assertions and descriptions for file
    download test by @zhaque44 in #1745
  * feat: add 'hide-notes' flag to helm in sync and apply commands
    by @yxxhero in #1746
* Wed Oct 16 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.169.0:
  * Add comment withPreparedCharts by @mumoshu in #1704
  * build(deps): bump k8s.io/apimachinery from 0.31.0 to 0.31.1
    by @dependabot in #1705
  * build(deps): bump helm.sh/helm/v3 from 3.15.4 to 3.16.1 by
    @dependabot in #1707
  * bump all helm to 3.16.1 by @yxxhero in #1708
  * add zhaque44 in CODEOWNERS by @yxxhero in #1711
  * Add hide notes support by @yxxhero in #1710
  * update python3 version for mkdoc.yaml by @zhaque44 in #1712
  * build(deps): bump dario.cat/mergo from 0.3.16 to 1.0.1 by
    @yxxhero in #1714
  * fix docs build errors by @zhaque44 in #1715
  * feat(pkg/app): Update Helm Diff version to v3.9.11 by
    @yxxhero in #1720
  * update test to table driven with assertions & test
    GetMergedValues by @zhaque44 in #1721
  * feat: update go version and adjust dependencies in Dockerfile
    and go.mod by @yxxhero in #1722
  * feat: Update Docker image to ubuntu:24.10 by @yxxhero in #1726
  * build(deps): bump github.com/zclconf/go-cty-yaml from 1.0.3 to
    1.1.0 by @dependabot in #1723
  * build(deps): bump golang.org/x/term from 0.24.0 to 0.25.0 by
    @dependabot in #1724
  * feat(pkg/policy): improve TopKeys function handling by
    @yxxhero in #1730
  * build(deps): bump helm.sh/helm/v3 from 3.16.1 to 3.16.2 by
    @dependabot in #1732
  * chore: Update AGE var version by @zhaque44 in #1731
  * feat(helm-version): Update helm version to v3.16.2 by @yxxhero
    in #1733
  * fix: duration of delete failures are always 0s by @felipecrs
    in #1734
  * [feature] add --skip-refresh to globals by @sstarcher in #1736
  * build(deps): bump github.com/helmfile/vals from 0.37.5 to
    0.37.6 by @dependabot in #1739
  * build(deps): bump github.com/helmfile/chartify from 0.20.2 to
    0.20.3 by @dependabot in #1738
  * feat: improve summary for releases failed to delete by
    @felipecrs in #1735
  * [feature] --skip-refresh to pass through to deps by @sstarcher
    in #1740
* Fri Sep 13 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.168.0:
  * chore: enhance TopKeys function & adding test cases for malformed
    lines scenario in TopKeys func by @zhaque44 in #1654
  * build(deps): bump golang.org/x/sync from 0.7.0 to 0.8.0 by
    @dependabot in #1655
  * feat: add isDir template function by @simonsystem in #1657
  * build(deps): bump golang.org/x/term from 0.22.0 to 0.23.0 by
    @dependabot in #1658
  * build(deps): bump github.com/docker/docker from 27.1.0+incompatible
    to 27.1.1+incompatible by @dependabot in #1662
  * build(deps): update Helm version to v3.15.4 by @yxxhero in #1668
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.5 to
    1.7.6 by @dependabot in #1666
  * build(deps): bump k8s.io/apimachinery from 0.30.3 to 0.31.0 by
    @dependabot in #1665
  * fix: CI linting issues with dockerfiles by @zhaque44 in #1671
  * chore: update dockerfile based on CI warnings by @zhaque44 in #1675
  * fix: _*.tpl files add whitespace to empty Namespace by
    @chrisdoherty4 in #1674
  * Add RightCapital to USERS.md by @yinheli in #1676
  * feat: update kustomize version by @zhaque44 in #1677
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.21.0 to
    2.22.0 by @dependabot in #1679
  * feat: adding ability for for charts to be pulled with plain HTTP
    by @ennekein in #1672
  * feat: skip chart prep for local by @zhaque44 in #1681
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.2.1 to
    3.3.0 by @dependabot in #1683
  * build(deps): bump github.com/Masterminds/sprig/v3 from 3.2.3 to
    3.3.0 by @dependabot in #1684
  * feat: upgrade to k8s version to a supported version for security
    compliance by @zhaque44 in #1686
  * feat: upgrade helm-diff plugin version to 3.9.10 by @yxxhero
    in #1688
  * feat: fix password registry leak of credentials by @zhaque44
    in #1687
  * fix verify stage for helmfile when use oci as chart by @yxxhero
    in #1661
  * feat: update golang minor version based on security vulnerability
    by @zhaque44 in #1690
  * build(deps): bump golang.org/x/term from 0.23.0 to 0.24.0 by
    @dependabot in #1689
  * feat: bump chartify versions by @yxxhero in #1693
  * optimize code by @Peoplelike in #1694
  * chore: Update Ubuntu image to LTS version 24.04 by @pathob
    in #1696
  * Fixed typo in configuration section by @vedrankolka in #1698
  * build(deps): bump github.com/helmfile/vals from 0.37.3 to 0.37.5
    by @dependabot in #1700
  * chore: add table driven tests for clarity by @zhaque44 in #1702
  * fix: two releases using the same chart in different version
    fails by @yxxhero in #1685
* Sun Aug  4 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.167.1:
  * build(deps): bump github.com/aws/aws-sdk-go from 1.55.3 to
    1.55.4 by @dependabot in #1649
  * fix(oci): use output-dir-template in path if specified by
    @henkka in #1648
  * build(deps): bump github.com/aws/aws-sdk-go from 1.55.4 to
    1.55.5 by @dependabot in #1651
  * build(deps): helm-s3: v0.16.0 -> v0.16.2 by @yxxhero in #1652
* Wed Jul 31 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.167.0:
  * Update GoReleaser configuration for version 2 by @yxxhero
    in #1600
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.7 to
    1.54.8 by @dependabot in #1602
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.8 to
    1.54.10 by @dependabot in #1607
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.10 to
    1.54.11 by @dependabot in #1608
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.11 to
    1.54.12 by @dependabot in #1610
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.12 to
    1.54.13 by @dependabot in #1611
  * Use logger for helm output by @inteon in #1585
  * build(deps): bump golang.org/x/term from 0.21.0 to 0.22.0
    by @dependabot in #1616
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.13 to
    1.54.14 by @dependabot in #1612
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.14 to
    1.54.15 by @dependabot in #1617
  * Fix broken links in status section of README.md by
    @jonathanmanton in #1618
  * build(deps): bump zipp from 3.7.0 to 3.19.1 in /docs by
    @dependabot in #1620
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.15 to
    1.54.17 by @dependabot in #1622
  * build(deps): bump google.golang.org/grpc from 1.64.0 to
    1.64.1 by @dependabot in #1621
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.17 to
    1.54.18 by @dependabot in #1625
  * feat: bump helm to 3.15.3 by @yxxhero in #1627
  * fix: inject KubeVersion and ApiVersions in Chartify rendering
    by @xabufr in #1624
  * chore: add tests for release filters by @zhaque44 in #1629
  * feat: add namespace info in syncRelease and diffRelease by
    @yxxhero in #1609
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.18 to
    1.54.19 by @dependabot in #1628
  * feat: add support for OCI auth through registry-config flag
    by @ThatsMrTalbot in #1630
  * build(deps): bump github.com/zclconf/go-cty from 1.14.4 to
    1.15.0 by @dependabot in #1632
  * feat: Update sops version 3.9.0 by @zhaque44 in #1634
  * build(deps): bump k8s.io/apimachinery from 0.30.2 to 0.30.3
    by @dependabot in #1635
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.19 to
    1.54.20 by @dependabot in #1638
  * build(deps): bump github.com/goccy/go-yaml from 1.11.3 to
    1.12.0 by @dependabot in #1631
  * chore: documentation updates: grammar & rm whitespace by
    @zhaque44 in #1639
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.20 to
    1.55.2 by @dependabot in #1644
  * build(deps): bump github.com/aws/aws-sdk-go from 1.55.2 to
    1.55.3 by @dependabot in #1645
  * chore: remove unecessary check in HandleExitCoder function and
    streamline logic by @zhaque44 in #1646
  * feat: use helm status to find helm release by @yxxhero in #1640
  * build(deps): bump github.com/docker/docker from
    27.0.1+incompatible to 27.1.0+incompatible by @dependabot in #1647
* Wed Jun 26 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.166.0:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.9 to
    1.53.10 by @dependabot in #1540
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.10 to
    1.53.11 by @dependabot in #1542
  * chore: add Incentive.me to the list of helmfile users by
    @gabriel-suela in #1545
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.11 to
    1.53.13 by @dependabot in #1546
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.13 to
    1.53.14 by @dependabot in #1549
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.14 to
    1.53.15 by @dependabot in #1552
  * build(deps): bump github.com/helmfile/vals from 0.37.1 to
    0.37.2 by @dependabot in #1551
  * build(deps): bump golang.org/x/term from 0.20.0 to 0.21.0
    by @dependabot in #1553
  * build(deps): bump goreleaser/goreleaser-action from 5 to 6
    by @dependabot in #1555
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.15 to
    1.53.17 by @dependabot in #1557
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.17 to
    1.53.18 by @dependabot in #1559
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.18 to
    1.53.19 by @dependabot in #1561
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.19 to
    1.53.20 by @dependabot in #1562
  * build(deps): bump github.com/Azure/azure-sdk-for-go/sdk/azidentity
    from 1.5.2 to 1.6.0 by @dependabot in #1564
  * fix: Incentive.me url on list of helmfile users by
    @gabriel-suela in #1570
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.20 to
    1.54.0 by @dependabot in #1568
  * build(deps): bump helm.sh/helm/v3 from 3.15.1 to 3.15.2 by
    @dependabot in #1565
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.0 to
    1.54.1 by @dependabot in #1571
  * build(deps): bump docker/build-push-action from 5 to 6 by
    @dependabot in #1575
  * build(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1
    by @dependabot in #1574
  * build(deps): bump k8s.io/apimachinery from 0.30.1 to 0.30.2
    by @dependabot in #1569
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.1 to
    1.54.2 by @dependabot in #1573
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.2 to
    1.54.3 by @dependabot in #1576
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.3 to
    1.54.5 by @dependabot in #1580
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.20.1 to
    2.21.0 by @dependabot in #1578
  * bump helm to 3.15.2 by @yxxhero in #1581
  * bump helm-diff to 3.9.8 by @yxxhero in #1582
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.5 to
    1.54.6 by @dependabot in #1583
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.4
    to 1.7.5 by @dependabot in #1587
  * build(deps): bump github.com/helmfile/vals from 0.37.2 to
    0.37.3 by @dependabot in #1588
  * build(deps): bump github.com/hashicorp/go-retryablehttp from
    0.7.6 to 0.7.7 by @dependabot in #1590
  * build(deps): bump github.com/go-test/deep from 1.1.0 to 1.1.1
    by @dependabot in #1589
  * build(deps): bump github.com/aws/aws-sdk-go from 1.54.6 to
    1.54.7 by @dependabot in #1594
  * fix windows glob issue by @yxxhero in #1572
  * fix CVE-2024-24790 on helmfile (#1592) by @LionnelC in #1593
- This update contains fixes for boo#1227002, boo#1227014 and
  boo#1227040
* Mon May 27 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.165.0:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.32 to
    1.52.0 by @dependabot in #1496
  * build(deps): bump github.com/helmfile/vals from 0.37.0 to
    0.37.1 by @dependabot in #1500
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.0 to
    1.52.1 by @dependabot in #1499
  * build(deps): bump jinja2 from 3.1.3 to 3.1.4 in /docs by
    @dependabot in #1505
  * build(deps): bump golang.org/x/term from 0.19.0 to 0.20.0
    by @dependabot in #1502
  * build(deps): bump github.com/helmfile/chartify from 0.20.0
    to 0.20.1 by @dependabot in #1503
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.1 to
    1.52.2 by @dependabot in #1501
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.2 to
    1.52.3 by @dependabot in #1507
  * build(deps): bump golangci/golangci-lint-action from 5 to 6 by @dependabot in #1506
  * Remove config key order check by @drivelikebrazil in #1504
  * Relax the helmfile.lock helmfile binary version constraint
    by @mumoshu in #1511
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.3 to
    1.52.4 by @dependabot in #1509
  * v1: Document experimental features by @mumoshu in #1512
  * Update the project status with invitation to v1 rc testers
    by @mumoshu in #1513
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.4 to
    1.52.5 by @dependabot in #1514
  * chore: upgrade kubectl to v1.28.9 by @rtomadpg in #1516
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.5 to
    1.52.6 by @dependabot in #1518
  * bump helm-diff to v3.9.6 by @yxxhero in #1517
  * Add helmfile template --show-only by @jim-barber-he in #1494
  * build(deps): bump github.com/aws/aws-sdk-go from 1.52.6 to
    1.53.0 by @dependabot in #1519
  * build(deps): bump k8s.io/apimachinery from 0.30.0 to 0.30.1
    by @dependabot in #1521
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.0 to
    1.53.2 by @dependabot in #1520
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.2 to
    1.53.3 by @dependabot in #1525
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.3 to
    1.53.4 by @dependabot in #1526
  * Fix typo and link for supported backends by @koenpunt in #1529
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.4 to
    1.53.5 by @dependabot in #1528
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.5 to
    1.53.6 by @dependabot in #1531
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.6 to
    1.53.7 by @dependabot in #1532
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.7 to
    1.53.8 by @dependabot in #1534
  * feat: bump helm to v3.15.1 by @yxxhero in #1523
  * build(deps): bump github.com/aws/aws-sdk-go from 1.53.8 to
    1.53.9 by @dependabot in #1535
  * bump helm-diff to 3.9.7 by @yxxhero in #1536
* Fri May  3 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.164.0:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.6 to
    1.51.7 by @dependabot in #1429
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.7 to
    1.51.8 by @dependabot in #1430
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.8 to
    1.51.9 by @dependabot in #1432
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.9 to
    1.51.10 by @dependabot in #1433
  * remove HELMFILE_SKIP_INSECURE_TEMPLATE_FUNCTIONS for v1 by
    @yxxhero in #1434
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.10 to
    1.51.11 by @dependabot in #1435
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.11 to
    1.51.12 by @dependabot in #1436
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.12 to
    1.51.13 by @dependabot in #1438
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.13 to
    1.51.14 by @dependabot in #1439
  * build(deps): bump golang.org/x/sync from 0.6.0 to 0.7.0 by
    @dependabot in #1441
  * build(deps): bump github.com/helmfile/vals from 0.36.0 to
    0.37.0 by @dependabot in #1440
  * build(deps): bump golang.org/x/term from 0.18.0 to 0.19.0
    by @dependabot in #1444
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.14 to
    1.51.15 by @dependabot in #1443
  * Misc documentation fixes by @StarlessNights in #1442
  * update deps versions by @yxxhero in #1446
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.15 to
    1.51.16 by @dependabot in #1447
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.16 to
    1.51.17 by @dependabot in #1448
  * build(deps): bump helm.sh/helm/v3 from 3.14.3 to 3.14.4 by
    @dependabot in #1451
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.17 to
    1.51.19 by @dependabot in #1450
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.19 to
    1.51.20 by @dependabot in #1452
  * bump helm to v3.14.4 by @yxxhero in #1453
  * build(deps): bump helm-git from v0.15.1 to v0.16.0 (minor) by
    @maxime1907 in #1455
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.20 to
    1.51.21 by @dependabot in #1456
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.3 to
    1.7.4 by @dependabot in #1457
  * build(deps): bump k8s.io/apimachinery from 0.29.3 to 0.29.4 by
    @dependabot in #1463
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.21 to
    1.51.22 by @dependabot in #1462
  * add NAMESPACE filed for diff by @yxxhero in #1460
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.22 to
    1.51.23 by @dependabot in #1466
  * build(deps): bump k8s.io/apimachinery from 0.29.4 to 0.30.0
    by @dependabot in #1465
  * chore(docs): update heading by @josephgardner in #1470
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.23 to
    1.51.24 by @dependabot in #1469
  * build(deps): bump github.com/helmfile/chartify from 0.18.1 to
    0.19.0 by @dependabot in #1468
  * Feature/support env hcl and interpolations by @XT-Phate in #1423
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.19.1 to
    2.20.1 by @dependabot in #1475
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.24 to
    1.51.25 by @dependabot in #1476
  * build(deps): bump github.com/zclconf/go-cty from 1.14.3 to
    1.14.4 by @dependabot in #1474
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.25 to
    1.51.26 by @dependabot in #1478
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.26 to
    1.51.27 by @dependabot in #1480
  * build(deps): bump golangci/golangci-lint-action from 4 to 5
    by @dependabot in #1482
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.27 to
    1.51.28 by @dependabot in #1481
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.28 to
    1.51.29 by @dependabot in #1485
  * Update DAG with dependencies by @vlpav030 in #1477
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.29 to
    1.51.30 by @dependabot in #1486
  * build(deps): bump github.com/helmfile/chartify from 0.19.0 to
    0.20.0 by @dependabot in #1487
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.30 to
    1.51.31 by @dependabot in #1488
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.31 to
    1.51.32 by @dependabot in #1489
* Tue Mar 26 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.163.1:
  What's Changed
  * build(deps): bump github.com/helmfile/vals from 0.35.0 to
    0.36.0 by @dependabot in #1421
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.4 to
    1.51.5 by @dependabot in #1420
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.5 to
    1.51.6 by @dependabot in #1422
  * skip helm dep up for kustomizations by @jouve in #1424
* Fri Mar 22 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.163.0:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.19 to
    1.50.20 by @dependabot in #1359
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.20 to
    1.50.21 by @dependabot in #1361
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.21 to
    1.50.22 by @dependabot in #1363
  * build(deps): bump go.uber.org/zap from 1.26.0 to 1.27.0 by
    @dependabot in #1362
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.22 to
    1.50.23 by @dependabot in #1367
  * build(deps): bump helm.sh/helm/v3 from 3.14.1 to 3.14.2 by
    @dependabot in #1366
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.23 to
    1.50.24 by @dependabot in #1369
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.24 to
    1.50.25 by @dependabot in #1371
  * feat: bump helm to v3.14.2 by @yxxhero in #1372
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.25 to
    1.50.26 by @dependabot in #1373
  * build(deps): bump github.com/helmfile/vals from 0.34.1 to
    0.35.0 by @dependabot in #1377
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.26 to
    1.50.28 by @dependabot in #1378
  * Add the SyncArgs option and --sync-args flag by @inteon
    in #1375
  * Add --kubeconfig flag by @inteon in #1381
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.28 to
    1.50.29 by @dependabot in #1382
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to
    1.9.0 by @dependabot in #1383
  * bump helm-diff to 3.9.5 by @yxxhero in #1384
  * fix needs issue when release installed is false by @yxxhero
    in #997
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.29 to
    1.50.30 by @dependabot in #1387
  * build(deps): bump golang.org/x/term from 0.17.0 to 0.18.0
    by @dependabot in #1389
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.30 to
    1.50.31 by @dependabot in #1388
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.31 to
    1.50.32 by @dependabot in #1390
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.32 to
    1.50.34 by @dependabot in #1395
  * build(deps): bump github.com/go-jose/go-jose/v3 from 3.0.1 to
    3.0.3 by @dependabot in #1393
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.34 to
    1.50.35 by @dependabot in #1396
  * Allow for conditions to have a deeper nested structure. by
    @vandycknick in #1360
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.35 to
    1.50.36 by @dependabot in #1397
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.36 to
    1.50.37 by @dependabot in #1400
  * Add Tudock GmbH to USERS.md by @jeliebig in #1399
  * build(deps): bump google.golang.org/protobuf from 1.32.0 to
    1.33.0 by @dependabot in #1403
  * build(deps): bump helm.sh/helm/v3 from 3.14.2 to 3.14.3 by
    @dependabot in #1404
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.37 to
    1.50.38 by @dependabot in #1405
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.38 to
    1.51.0 by @dependabot in #1406
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.0 to
    1.51.1 by @dependabot in #1410
  * build(deps): bump k8s.io/apimachinery from 0.29.2 to 0.29.3
    by @dependabot in #1409
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.1 to
    1.51.2 by @dependabot in #1413
  * build(deps): bump github.com/docker/docker from
    24.0.7+incompatible to 24.0.9+incompatible by @dependabot
    in #1416
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.2 to
    1.51.3 by @dependabot in #1415
  * build(deps): bump github.com/aws/aws-sdk-go from 1.51.3 to
    1.51.4 by @dependabot in #1417
  * feat: bump helm to 3.14.3 by @yxxhero in #1418
* Mon Feb 19 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.162.0:
  New feature
  * add suppress output line regex support by @yxxhero in #1329
    see more: https://github.com/helmfile/helmfile/blob/v0.162.0/test/integration/test-cases/suppress-output-line-regex/input/helmfile.yaml.gotmpl
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.1 to
    1.50.2 by @dependabot in #1309
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.2 to
    1.50.3 by @dependabot in #1312
  * feat: document that jsonPatches et al can be files by
    @rsrchboy in #1313
  * build(deps): bump github.com/goccy/go-yaml from 1.11.2 to
    1.11.3 by @dependabot in #1314
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.3 to
    1.50.4 by @dependabot in #1315
  * feat: Bump helm-diff to 3.9.4 by @yxxhero in #1316
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.4 to
    1.50.5 by @dependabot in #1318
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.5 to
    1.50.6 by @dependabot in #1319
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.6 to
    1.50.7 by @dependabot in #1321
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.7 to
    1.50.8 by @dependabot in #1322
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.8 to
    1.50.9 by @dependabot in #1323
  * disable version check for sops while building container
    image by @itscaro in #1320
  * build(deps): bump github.com/helmfile/vals from 0.33.0 to
    0.33.1 by @dependabot in #1325
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.9 to
    1.50.10 by @dependabot in #1324
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.10 to
    1.50.11 by @dependabot in #1328
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.11 to
    1.50.12 by @dependabot in #1330
  * feat: update to use go 1.22 by @chenrui333 in #1332
  * build(deps): bump golang.org/x/term from 0.16.0 to 0.17.0
    by @dependabot in #1334
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.12 to
    1.50.13 by @dependabot in #1333
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.13 to
    1.50.14 by @dependabot in #1336
  * build(deps): bump golangci/golangci-lint-action from 3 to 4
    by @dependabot in #1338
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.14 to
    1.50.15 by @dependabot in #1337
  * build(deps): bump github.com/helmfile/vals from 0.33.1 to
    0.34.1 by @dependabot in #1339
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.15 to
    1.50.17 by @dependabot in #1342
  * build(deps): bump github.com/helmfile/chartify from 0.17.0 to
    0.18.1 by @dependabot in #1341
  * fix: use finer-grained locking when listing releases for diff
    by @steved in #1343
  * run deps without chart preparation by @jouve in #1011
  * build(deps): bump k8s.io/apimachinery from 0.29.1 to 0.29.2
    by @dependabot in #1348
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.17 to
    1.50.18 by @dependabot in #1347
  * build(deps): bump helm.sh/helm/v3 from 3.14.0 to 3.14.1
    by @dependabot in #1346
  * fix: version path issue by @yxxhero in #1344
  * Make it clear that the plugin install prompt is a question
    by @wallrj in #1355
  * Update Helm version to v3.14.1 by @yxxhero in #1352
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.18 to
    1.50.19 by @dependabot in #1357
  * feat: add suppress output line regex support by @yxxhero
    in #1329
- Use go1.22 for building.
* Wed Jan 24 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.161.0:
  What's Changed
  * build(deps): bump github.com/helmfile/vals from 0.31.0 to
    0.32.0 by @dependabot in #1250
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.8 to
    1.49.9 by @dependabot in #1251
  * feat: respect helmfile.lock with ad-hoc kustimzation by
    @vlpav030 in #1244
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.9 to
    1.49.10 by @dependabot in #1257
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.10 to
    1.49.11 by @dependabot in #1259
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.11 to
    1.49.12 by @dependabot in #1260
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.12 to
    1.49.13 by @dependabot in #1263
  * fix: prevent preparing chart for disabled releases by
    @mighty1231 in #1210
  * add support for HELMFILE_FILE_PATH envvar to set -f by
    @sstarcher in #1255
  * fix checker error message by @petelock in #1266
  * build(deps): bump golang.org/x/term from 0.15.0 to 0.16.0
    by @dependabot in #1267
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.13 to
    1.49.14 by @dependabot in #1269
  * build(deps): bump golang.org/x/sync from 0.5.0 to 0.6.0 by
    @dependabot in #1268
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.14 to
    1.49.15 by @dependabot in #1270
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.15 to
    1.49.16 by @dependabot in #1272
  * build(deps): bump github.com/cloudflare/circl from 1.3.3 to
    1.3.7 by @dependabot in #1273
  * feat: include func support more template functions by
    @yxxhero in #1277
  * chore: add zhihu to list of helmfile users by @zhaogaolong
    in #1278
  * Bugfix: do not print registry password to stdout when running
    by @ennekein in #1275
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.16 to
    1.49.17 by @dependabot in #1279
  * build(deps): bump gitpython from 3.1.37 to 3.1.41 in /docs
    by @dependabot in #1280
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.17 to
    1.49.18 by @dependabot in #1283
  * build(deps): bump jinja2 from 3.1.1 to 3.1.3 in /docs by
    @dependabot in #1284
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.18 to
    1.49.19 by @dependabot in #1285
  * feat: bump helm-diff to v3.9.1 by @yxxhero in #1286
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.19 to
    1.49.21 by @dependabot in #1287
  * Bump helm diff to 3.9.2 by @kxkcx in #1291
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.21 to
    1.49.22 by @dependabot in #1292
  * fix: issue with pre-release Helm version by @yxxhero in #1293
  * build(deps): bump k8s.io/apimachinery from 0.29.0 to 0.29.1
    by @dependabot in #1298
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.22 to
    1.49.23 by @dependabot in #1296
  * Bump helm diff to 3.9.2 by @kxkcx in #1299
  * feat: bump helm to 3.14.0 by @yxxhero in #1295
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.23 to
    1.49.24 by @dependabot in #1300
  * feat: bump vals to 0.33.0 by @yxxhero in #1302
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.24 to
    1.50.0 by @dependabot in #1303
  * build(deps): bump github.com/aws/aws-sdk-go from 1.50.0 to
    1.50.1 by @dependabot in #1305
  * Fix the password display problem when passing the chart link
    by @NavesEdu in #1281
* Tue Dec 26 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.160.0:
  What's Changed
  * build(deps): bump golang.org/x/term from 0.14.0 to 0.15.0 by
    @dependabot in #1170
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.3 to
    1.48.4 by @dependabot in #1171
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.4 to
    1.48.6 by @dependabot in #1173
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.6 to
    1.48.7 by @dependabot in #1176
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.7 to
    1.48.9 by @dependabot in #1179
  * Fix failing docs build by @josephgardner in #1186
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.9 to
    1.48.10 by @dependabot in #1181
  * [dockerfile] latest sops by @jouve in #1185
  * [dockerfile] update plugins by @jouve in #1182
  * [dockerfile] age 1.1.1 by @jouve in #1183
  * [dockerfile] latest kubectl 1.25 by @jouve in #1184
  * [dockerfile] update latest kustomize by @jouve in #1188
  * feat: include func support by @yxxhero in #1187
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.10 to
    1.48.11 by @dependabot in #1190
  * Create DeleteWait and DeleteTimeout parameters for Destroy by
    @virginiabrioso in #1177
  * Allow secrets to be excluded from release template inheritance
    by @voron in #1189
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.11 to
    1.48.12 by @dependabot in #1191
  * fix(docs): specify python version by @josephgardner in #1193
  * fix(docs): typo in templating_funcs.md by @yxxhero in #1194
  * build(deps): bump github.com/helmfile/vals from 0.29.0 to
    0.30.0 by @dependabot in #1192
  * fix(docs): pin python to 3.11 by @josephgardner in #1197
  * chore(docs): update link by @josephgardner in #1198
  * build(deps): bump actions/setup-go from 4 to 5 by @dependabot
    in #1196
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.12 to
    1.48.13 by @dependabot in #1195
  * chore(docs): Add missing template funcs by @josephgardner in
    [#1201]
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.13 to
    1.48.14 by @dependabot in #1200
  * fix: --state-values-set unable to set booleans by
    @tunahansezen in #1199
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.14 to
    1.48.15 by @dependabot in #1202
  * chore: add bluelabs to list of helmfile users by @efcasado
    in #1206
  * consistently use Masterminds/semver by @jouve in #1209
  * simplify multierr usage with standard errors by @jouve in
    [#1208]
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.15 to
    1.48.16 by @dependabot in #1211
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.16 to
    1.49.0 by @dependabot in #1214
  * replace custom diff in tests using testify by @jouve in #1215
  * fix: ConditionEnabled panic issue by @yxxhero in #1221
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.0 to
    1.49.1 by @dependabot in #1223
  * bump helm version to 3.13.3 by @yxxhero in #1225
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.1 to
    1.49.2 by @dependabot in #1227
  * build(deps): bump k8s.io/apimachinery from 0.28.4 to 0.29.0
    by @dependabot in #1226
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.2 to
    1.49.3 by @dependabot in #1231
  * build(deps): bump github.com/helmfile/vals from 0.30.0 to
    0.31.0 by @dependabot in #1230
  * build(deps): bump actions/upload-artifact and
    actions/download-artifact from 3 to 4 by @yxxhero in #1234
  * build(deps): bump golang.org/x/crypto from 0.15.0 to 0.17.0
    by @dependabot in #1238
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.3 to
    1.49.4 by @dependabot in #1236
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.4 to
    1.49.5 by @dependabot in #1240
  * build(deps): bump github.com/containerd/containerd from
    1.7.6 to 1.7.11 by @dependabot in #1241
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.5 to
    1.49.6 by @dependabot in #1242
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.6 to
    1.49.7 by @dependabot in #1246
  * build(deps): bump github.com/aws/aws-sdk-go from 1.49.7 to
    1.49.8 by @dependabot in #1247
* Wed Nov 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.159.0:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.7 to
    1.47.0 by @dependabot in #1111
  * docs: fix indentation error in index.md by @tjanson in #1114
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.0 to
    1.47.1 by @dependabot in #1113
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.1 to
    1.47.2 by @dependabot in #1117
  * fix: args ignore in diff subcommand by @yxxhero in #1118
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.2 to
    1.47.3 by @dependabot in #1125
  * build(deps): bump golang.org/x/sync from 0.4.0 to 0.5.0 by
    @dependabot in #1124
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0
    by @dependabot in #1123
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.3 to
    1.47.4 by @dependabot in #1126
  * resolved deps even when installed=false by @jouve in #1120
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.4 to
    1.47.5 by @dependabot in #1127
  * build(deps): bump helm.sh/helm/v3 from 3.13.1 to 3.13.2 by
    @dependabot in #1128
  * build(deps): bump golang.org/x/term from 0.13.0 to 0.14.0
    by @dependabot in #1129
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.5 to
    1.47.7 by @dependabot in #1134
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.7 to
    1.47.8 by @dependabot in #1138
  * fix: support large output with --enable-live-ouput by
    @flabatut in #1139
  * bump helm to 3.13.2 by @yxxhero in #1130
  * Update helmfile/chartify to v0.17.0 by @moririnson in #1140
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.8 to
    1.47.9 by @dependabot in #1141
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.9 to
    1.47.10 by @dependabot in #1143
  * build(deps): bump dessant/lock-threads from 4 to 5
    by @dependabot in #1144
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.10 to
    1.47.11 by @dependabot in #1146
  * build(deps): bump k8s.io/apimachinery from 0.28.3 to 0.28.4 by
    @dependabot in #1149
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.11 to
    1.47.12 by @dependabot in #1150
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.12 to
    1.47.13 by @dependabot in #1152
  * fix checker for empty array case by @yxxhero in #1153
  * build(deps): bump github.com/aws/aws-sdk-go from 1.47.13 to
    1.48.0 by @dependabot in #1156
  * build(deps): bump github.com/helmfile/vals from 0.28.1 to
    0.29.0 by @dependabot in #1155
  * Add "PostRendererArgs" option to be passed to helm by
    @boekhold in #1133
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.0 to
    1.48.1 by @dependabot in #1159
  * build(deps): bump github.com/go-jose/go-jose/v3 from 3.0.0 to
    3.0.1 by @dependabot in #1160
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.1 to
    1.48.2 by @dependabot in #1162
  * update get and getOrNil docs by @yxxhero in #1164
  * build(deps): bump github.com/aws/aws-sdk-go from 1.48.2 to
    1.48.3 by @dependabot in #1166
* Thu Nov  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.158.1:
  What's Changed
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.0 to 1.46.1
    by @dependabot in #1090
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.1 to 1.46.2
    by @dependabot in #1091
  * fix issue 1093 by @yxxhero in #1094
  * build(deps): bump google.golang.org/grpc from 1.58.1 to 1.58.3 by
    @dependabot in #1099
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.2 to 1.46.3
    by @dependabot in #1097
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.3 to 1.46.4
    by @dependabot in #1101
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.4 to 1.46.5
    by @dependabot in #1102
  * enable run skip-diff-output tests by @yxxhero in #1104
  * fix golang lint error by @yxxhero in #1106
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.5 to 1.46.6
    by @dependabot in #1107
  * build(deps): bump github.com/docker/docker from 24.0.6+incompatible
    to 24.0.7+incompatible by @dependabot in #1108
  * fix chartify with non-chart dir by @yxxhero in #1105
  * build(deps): bump github.com/aws/aws-sdk-go from 1.46.6 to 1.46.7
    by @dependabot in #1109
  * fix #1095 by @yxxhero in #1100
* Fri Oct 27 2023 Manfred Hollstein <manfred.h@gmx.net>
- autocomplete files can be generated using "helmfile complete" for
  the shells "bash", "zsh" and "fish". Use this feature to provide
  additional helmfile-<shell>-completion packages again.
* Tue Oct 24 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.158.0:
  What's Changed
  * feat: add an option to set a custom kustomize binary by
    @alessiodionisi in #1012
  * feat: bump helm to 3.13.0 by @yxxhero in #1044
  * feat: skip deps when installed is false by @yxxhero in #1054
  * feat: add duration to failed releases summary by @felipecrs
    in #1066
  * feat: bump helm version to 3.13.1 of tests by @yxxhero in #1068
  * feat: support most remote urls by @xiaomudk in #1061
  * Add diffArgs to helmDefaults by @yktakaha4 in #1019
  * Fix symlink behaviour by @reegnz in #1020
  * fix: security/dependabot/33 by @yxxhero in #1025
  * by @lucasfcnunes in #1028
  * optimize OCI chart version check by @yxxhero in #1052
  * optimize flag logic about wait by @yxxhero in #1051
  * doc: remote Environment values support more protocols by
    @xiaomudk in #1089
  * add more tests for Desired func by @yxxhero in #1082
  * upgrade helm in dockerfile images by @jouve in #1067
  * replace all mozilla/sops with getsops/sops
  * test: fix running tests locally by @felipecrs in #1088
  * build(deps): bump docker/login-action from 2 to 3 by
    @dependabot in #1018
  * build(deps): bump docker/metadata-action from 4 to 5 by
    @dependabot in #1017
  * build(deps): bump docker/build-push-action from 4 to 5 by
    @dependabot in #1016
  * build(deps): bump docker/setup-qemu-action from 2 to 3 by
    @dependabot in #1015
  * build(deps): bump goreleaser/goreleaser-action from 4 to 5 by
    @dependabot in #1014
  * build(deps): bump docker/setup-buildx-action from 2 to 3 by
    @dependabot in #1022
  * build(deps): bump go.uber.org/zap from 1.25.0 to 1.26.0 by
    @dependabot in #1032
  * build(deps): bump github.com/goccy/go-yaml from 1.11.0 to
    1.11.2 by @dependabot in #1031
  * build(deps): bump golang.org/x/term from 0.11.0 to 0.12.0
    by @dependabot in #1033
  * build(deps): bump helm.sh/helm/v3 from 3.12.3 to 3.13.0
    by @dependabot in #1045
  * build(deps): bump github.com/cyphar/filepath-securejoin from
    0.2.3 to 0.2.4 by @dependabot in #1026
  * build(deps): bump github.com/helmfile/vals from 0.27.1 to
    0.28.0 by @dependabot in #1048
  * build(deps): bump golang.org/x/term from 0.12.0 to 0.13.0
    by @dependabot in #1055
  * build(deps): bump golang.org/x/sync from 0.3.0 to 0.4.0
    by @dependabot in #1056
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.2
    to 1.7.3 by @dependabot in #1058
  * build(deps): bump gitpython from 3.1.35 to 3.1.37 in /docs by
    @dependabot in #1059
  * build(deps): bump github.com/google/go-cmp from 0.5.9 to 0.6.0
    by @dependabot in #1060
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.17.0 by
    @dependabot in #1063
  * build(deps): bump helm.sh/helm/v3 from 3.13.0 to 3.13.1 by
    @dependabot in #1065
  * build(deps): bump github.com/helmfile/vals from 0.28.0 to 0.28.1
    by @dependabot in #1071
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.251 to
    1.45.27 by @dependabot in #1076
  * build(deps): bump github.com/aws/aws-sdk-go from 1.45.27 to
    1.45.28 by @dependabot in #1083
  * build(deps): bump k8s.io/apimachinery from 0.28.2 to 0.28.3
    by @dependabot in #1084
  * build(deps): bump github.com/aws/aws-sdk-go from 1.45.28 to
    1.46.0 by @dependabot in #1085
* Thu Oct 12 2023 Manfred Hollstein <manfred.h@gmx.net>
- Use go1.21 for building.
- Bump helm to v3.13.1
* Fri Sep 15 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.157.0:
  What's Changed
  * bump github.com/helmfile/vals by @jkroepke in #982
  * fix snapshot tests random error by @yxxhero in #985
  * feat: keyring supportting by @yxxhero in #984
  * update keyring docs by @yxxhero in #986
  * Update docs for running as container by @PointyShinyBurning
    in #988
  * Add missing documentation for isFile function by @anessi in #996
  * Update workflows by @bonddim in #998
  * build(deps): bump actions/checkout from 3 to 4 by @dependabot
    in #999
  * build(deps): bump gitpython from 3.1.32 to 3.1.34 in /docs
    by @dependabot in #1004
  * chore: added a note in the doc. by @rlnchow in #1006
  * build(deps): bump gitpython from 3.1.34 to 3.1.35 in /docs by
    @dependabot in #1008
- Update to version 0.156.0:
  What's Changed
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.1 to
    1.7.2 by @dependabot in #949
  * build(deps): bump go.uber.org/zap from 1.24.0 to 1.25.0 by
    @dependabot in #957
  * build(deps): bump github.com/helmfile/chartify from 0.14.0 to
    0.15.0 by @dependabot in #956
  * build(deps): bump github.com/helmfile/vals from 0.26.1 to
    0.26.2 by @dependabot in #962
  * build(deps): bump golang.org/x/term from 0.10.0 to 0.11.0
    by @dependabot in #961
  * fix re-using environment state in sub-helmfiles issue by
    @yxxhero in #951
  * feat: add friendly tips for helmfile config order by @yxxhero
    in #710
  * chore: join with space by @wrenix in #963
  * Implement --diff-args by @jkroepke in #959
  * build(deps): bump gitpython from 3.1.30 to 3.1.32 in /docs
    by @dependabot in #970
  * build(deps): bump helm.sh/helm/v3 from 3.12.2 to 3.12.3
    by @dependabot in #968
  * bump helm to v3.12.3 by @yxxhero in #971
  * bump go to 1.21 by @yxxhero in #972
  * Support functions written by KCL to mutate or validate
    manifests for Helmfile @Peefy #827
* Sat Aug 12 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.155.1:
  What's Changed
  * feat: add --insecure-skip-tls-verify support for helmfile
    template by @yxxhero in #916
  * feat: Allow to skip diff output on release base by @jkroepke
    in #906
  * build(deps): bump golang.org/x/term from 0.9.0 to 0.10.0 by
    @dependabot in #918
  * build(deps): bump helm.sh/helm/v3 from 3.12.1 to 3.12.2 by
    @dependabot in #930
  * build(deps): bump github.com/docker/docker from
    23.0.1+incompatible to 23.0.3+incompatible by @dependabot in #932
  * bump helm to v3.12.2 by @yxxhero in #933
  * build(deps): bump k8s.io/apimachinery from 0.27.3 to 0.27.4
    by @dependabot in #936
  * build(deps): bump github.com/helmfile/vals from 0.25.0 to
    0.26.0 by @dependabot in #938
  * Cancel rendering helmfile parts once the missing env is
    detected in the previous part by @mumoshu in #941
  * fix typo by @lucasfcnunes in #940
  * fix: oci pull directory conflict when download twice by
    @yxxhero in #914
  * feat: add insecure support for oci repo by @yxxhero in #921
  * add bug to exempt labels on git stale.yml by @lucasfcnunes
    in #942
  * build(deps): bump github.com/helmfile/vals from 0.26.0 to
    0.26.1 by @dependabot in #944
* Thu Jul  6 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.155.0:
  What's Changed
  * fix: more stringent condition checking by @thejan2009 in #869
  * build(deps): bump github.com/imdario/mergo from 0.3.15 to 0.3.16
    by @dependabot in #873
  * build(deps): bump github.com/stretchr/testify from 1.8.3 to
    1.8.4 by @dependabot in #876
  * feat: update repo Spec var type skipTLSVerify to bool by
    @yxxhero in #877
  * feat: set RepositorySpec.PassCredentials var type to bool by
    @yxxhero in #878
  * cleanup: remove tls configures about helm v2 by @yxxhero in #880
  * Upgrade helm diff version by @yxxhero in #883
  * Add insecure skip tls verify support by @yxxhero in #882
  * chore(docs): fix table by @josephgardner in #881
  * Feat: add --strip-args-values-on-exit-error by @jkroepke in #887
  * Stop failing on single helmfile part missing specified env by
    @mumoshu in #885
  * fix(docs): table and list formatting by @josephgardner in #891
  * add unittest for storage by @yxxhero in #894
  * cleanup: remove panic in testutil by @yxxhero in #890
  * fix: chartifyOpts ignore release set values by @yxxhero in #896
  * build(deps): bump golang.org/x/term from 0.8.0 to 0.9.0 by
    @dependabot in #897
  * build(deps): bump golang.org/x/sync from 0.2.0 to 0.3.0 by
    @dependabot in #898
  * bump helm to v3.12.1 by @yxxhero in #899
  * build(deps): bump k8s.io/apimachinery from 0.27.2 to 0.27.3 by
    @dependabot in #900
  * replace interface{} by any by @yxxhero in #901
  * fix set-file cannot find the file on windows by @xiaomudk in #908
  * feat: add starhistory by @yxxhero in #909
- Update to version 0.154.0:
  What's Changed
  * Feat: support helm flag --enable-dns by @vincentstchu in #830
  * Make helmfile respect signals send by kill command (not only
    Ctrl+C in terminal) by @dm3ch in #750
  * build(deps): bump golang.org/x/term from 0.7.0 to 0.8.0 by
    @dependabot in #846
  * build(deps): bump golang.org/x/sync from 0.1.0 to 0.2.0 by
    @dependabot in #847
  * feat: add --skip-trailing-cr to helmfile diff by @rezonant
    in #625
  * fix: loadBases overrodeEnv issue by @yxxhero in #838
  * build(deps): bump go.szostok.io/version from 1.1.0 to 1.2.0
    by @dependabot in #852
  * bump helm to v3.12.0 by @yxxhero in #855
  * build(deps): bump github.com/docker/distribution from
    2.8.1+incompatible to 2.8.2+incompatible by @dependabot in #857
  * Feat add cascade support by @yxxhero in #860
  * docs: update cascade by @yxxhero in #861
  * fix extra args missing in helmfile apply subcommand by
    @yxxhero in #858
  * build(deps): bump k8s.io/apimachinery from 0.27.1 to 0.27.2
    by @dependabot in #865
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to
    1.8.3 by @dependabot in #866
  * feat: make environment context available by @SeWieland in #832
  * Fix set flag are ignored when used in conjunction with
    jsonPatches by @xiaomudk in #867
* Thu May  4 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.153.1:
  What's Changed:
  * Properly emulated arm64 Docker builds by @lavifb in #826
- Update to version 0.153.0:
  What's Changed:
  * build(deps): bump go.uber.org/multierr from 1.10.0 to 1.11.0
    by @dependabot in #772
  * feat: add/expose cli flags by @hans-m-song in #771
  * build(deps): bump github.com/goccy/go-yaml from 1.10.1 to
    1.11.0 by @dependabot in #778
  * Bump github.com/helmfile/vals by @jkroepke in #781
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0
    by @dependabot in #783
  * build(deps): bump github.com/docker/docker from
    20.10.21+incompatible to 20.10.24+incompatible by @dependabot
    in #784
  * Update USERS.md by @AndreiBrandes in #777
  * build(deps): bump golang.org/x/term from 0.6.0 to 0.7.0 by
    @dependabot in #789
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.2.0
    to 3.2.1 by @dependabot in #796
  * Documentation updated about kubeVersion field by @Edu-DevOps
    in #797
  * build(deps): bump k8s.io/apimachinery from 0.26.3 to 0.27.0
    by @dependabot in #801
  * bump helm to v3.11.3 by @yxxhero in #802
  * fix: ValuesTemplate quote issue by @yxxhero in #787
  * feat: add duration to affected releases on sync by @AlexAxenti
    in #773
  * Add kube version flag by @FeLvi-zzz in #804
  * bump vals to v0.25.0 by @stoned in #808
  * build(deps): bump k8s.io/apimachinery from 0.27.0 to 0.27.1 by
    @dependabot in #810
  * Add documentation on internal environment variables by @voron
    in #811
  * Doc fixes by @stoned in #812
  * Fix inherit examples following #674 by @stoned in #815
  * Fix Markdown rendering of indented code blocks by @stoned
    in #814
  * Uniformize usage message by @stoned in #813
  * Build correct arch for container image by @lavifb in #817
  * Fix depedency binaries for arm64 builds by @lavifb in #820
  * chore(release): fix condition for latest tag by @rmoreas
    in #823
* Thu Mar 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.152.0:
  What's Changed:
  * build(deps): bump golang.org/x/net from 0.5.0 to 0.7.0 by
    @dependabot in #704
  * optimize logger code by @yxxhero in #706
  * Use Masterminds/semver/v3 instead of hashicorp/go-version by
    @johejo in #712
  * fix cobra issue by @yxxhero in #715
  * issue with in process label will never be considered stale by
    @yxxhero in #716
  * fix: update file help message by @yxxhero in #714
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to
    1.8.2 by @dependabot in #717
  * build(deps): bump k8s.io/apimachinery from 0.26.1 to 0.26.2 by
    @dependabot in #720
  * fix build-in objects docs by @yxxhero in #719
  * fix get template func by @yxxhero in #721
  * v1: Fix --state-values-set to override values of environments
    colocated with releases by @yxxhero in #705
  * build(deps): bump golang.org/x/term from 0.5.0 to 0.6.0 by
    @dependabot in #728
  * fix: improve set and values flags help message by @yxxhero in
    [#724]
  * build(deps): bump go.uber.org/multierr from 1.9.0 to 1.10.0 by
    @dependabot in #731
  * bump helm to 3.11.2 by @yxxhero in #733
  * build(deps): bump github.com/helmfile/vals from 0.22.0 to
    0.23.0 by @dependabot in #735
  * clean: helm v2 logic code by @yxxhero in #736
  * clean: optimize postrenderer code by @yxxhero in #738
  * fix concurrency issue by @yxxhero in #742
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.0 to
    1.7.1 by @dependabot in #745
  * bump mergo to 0.3.14 by @yxxhero in #751
  * chore(ci): use docker/metadata-action by @rmoreas in #756
  * build(deps): bump k8s.io/apimachinery from 0.26.2 to 0.26.3 by
    @dependabot in #758
  * bump chartify to v0.14.0 by @yxxhero in #759
  * feat: use new helm version parse function by @yxxhero in #760
  * build(deps): bump github.com/imdario/mergo from 0.3.14 to 0.3.15
    by @dependabot in #762
  * chore(release): add latest tag only on release tags by @rmoreas
    in #766
  * fix: formatting of YAML samples in 1.0 proposal doc by @smlx in
    [#767]
  * feat: use offical goccy/go-yaml by @yxxhero in #769
  * fix: goccy/go-yaml tests by @yxxhero in #770
  * remove unnecessary remote.Locate() by @itscaro in #565
* Mon Feb 20 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.151.0:
  New features:
  * Add --skip-charts for destroy for disable prepare charts (#637)
  * Add missingFileHandlerConfig.ignoreMissingGitBranch (#645)
  * Disable double-rendering in V1 (#647)
  * Add gotmpl file ext when using helmfile.d feature (#649)
  * Add chinese readme (#664)
  * Add post-renderer flag for diff and template subcommand (#691)
  * Support helm 3.11.1
  What's Changed:
  * feat: add paths-ignore to ci.yaml and lint.yaml by @gaius-qi in #631
  * build(deps): bump github.com/containerd/containerd from 1.6.6 to
    1.6.12 by @dependabot in #632
  * fix inherit chart empty check issue by @yxxhero in #635
  * build(deps): bump k8s.io/apimachinery from 0.26.0 to 0.26.1 by
    @dependabot in #641
  * add --skip-charts for destroy for disable prepare charts by
    @yxxhero in #637
  * bump helm to v3.11.0 by @yxxhero in #639
  * Remove unused go-getter driver funcs by @mumoshu in #643
  * Fix a minor typo in the v1 proposal by @mumoshu in #646
  * feat: Add missingFileHandlerConfig.ignoreMissingGitBranch by
    @mumoshu in #645
  * remove helm v2 code in tests by @yxxhero in #648
  * Do not load the legacy default charts.yaml in v1 by @mumoshu
    in #651
  * Disable double-rendering in V1 by @mumoshu in #647
  * use latest helm previous minor version for helmfile init by
    @yxxhero in #652
  * feat: add gotmpl file ext when using helmfile.d feature by
    @yxxhero in #649
  * fix(docs): transfer issue link for Docs site by @ChetanGoti
    in #655
  * update examples info by @yxxhero in #658
  * update hooks docs by @yxxhero in #657
  * Bring up the init command in readme #661 by @AmazingTurtle
    in #662
  * docs: Running helmfile withought an internet connection by
  - -skip-deps option by @toyamagu-2021 in #659
  * Reformat v1 proposal by @mumoshu in #663
  * add build-in objects docs by @yxxhero in #667
  * Add chinese readme by @xiaomudk in #664
  * fix typo by @yxxhero in #670
  * Bump Go to 1.20 by @yxxhero in #672
  * Use goccy/go-yaml fork to not break dynamic values on helmfile
    v1 by @mumoshu in #675
  * Improve readme readability by @xiaomudk in #678
  * Sync Chinese readme by @xiaomudk in #676
  * breaking: Fix the inherit feature to support multi-inheritance
    by @mumoshu in #674
  * fix: Make the forbid-env-with-releases policy strict on v1 by
    @mumoshu in #683
  * Remove references to .tpl from v1 proposal by @mumoshu in #685
  * build(deps): bump golang.org/x/term from 0.4.0 to 0.5.0 by
    @dependabot in #686
  * Relax the forbid-env-with-releases policy for plain helmfile.yaml
    on v1 by @mumoshu in #684
  * build(deps): bump helm.sh/helm/v3 from 3.11.0 to 3.11.1 by
    @dependabot in #689
  * Fix a typo in the v1 proposal by @mumoshu in #688
  * fix panic issue by @yxxhero in #690
  * bump helm to 3.11.1 by @yxxhero in #695
  * Fix post-renderer flag not working in diff and template
    subcommand by @xiaomudk in #691
  * fix: repos command help message by @yamagai in #698
  * build(deps): bump github.com/hashicorp/go-getter from 1.6.2 to
    1.7.0 by @dependabot in #697
  * build(deps): bump github.com/containerd/containerd from 1.6.15
    to 1.6.18 by @dependabot in #701
  * bump chartify to v0.13.0 by @yxxhero in #702
  * bump vals to v0.22.0 by @yxxhero in #703
* Thu Feb  9 2023 Manfred Hollstein <manfred.h@gmx.net>
- CVE-2023-25165: Require helm >= 3.11.1
* Mon Jan 23 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.150.0:
  New features:
  * We introduced a new Helmfile V1 mode that can be enabled via an
    environment variable and a build flag. It allows you to build a
    Helmfile V1 binary from the same source tree and even enabling
    the V1 mode at runtime via an environment variable:
    HELMFILE_V1MODE=true
  * The new V1 mode and upcoming Helmfile v1 releases have some
    breaking changes like the .gotmpl extension is required to let
    Helmfile render the helmfile.yaml as a template. See the V1
    proposal for more information.
  * We also reverted our YAML library to gopkg.in/yaml.v2 and
    introduced goccy/go-yaml for the Helmfile V1 mode. You can
    opt-in for the V1 mode or enable the new YAML library via
    environment variables: HELMFILE_GOCCY_GOYAML=true. Please note
    that the default yaml parser disables yaml overwrite feature.
  * If you've been struggling with managing and repeating common
    fields across releases, or worked-around that by either
    leveraging helmfile templates(not release templates) or
    layering values and valuesTemplate (although it wasn't the
    intended usage), the new inherit field would be handy.
    It allows you to layer any number of release templates.
  * The last and most important change is that we finally dropped
    the Helm v2 support! Helm v2 has been unmaintained since 2020,
    and no one should be using it anymore.
  What's Changed:
  * Clarify postsync hooks docs by @felipecrs in #585
  * optimize lint logic by @yxxhero in #586
  * use yaml v3 UnmarshalYAML by @yxxhero in #587
  * doc: Remove HELMFILE_SKIP_INSECURE_TEMPLATE_FUNCTIONS in
    Helmfile v1 by @mumoshu in #590
  * Add helmfile state validate policy by @yxxhero in #592
  * add goreportcard by @yxxhero in #595
  * feat: Helmfile V1 mode by @mumoshu in #594
  * Re: Strict helmfile.yaml file ext when rendered as template
    by @mumoshu in #599
  * Re: Remove deprecated args and cmd for v1.0.0 by @mumoshu in #598
  * Sops and gpg command by @metajiji in #597
  * Use goccy/go-yaml for v1 / Prep bringing back go-yaml v2 for
    v0.x by @mumoshu in #604
  * fix env value lost in environment values by @yxxhero in #605
  * Fix cryptic message on values template render error by
    @mumoshu in #607
  * feat: inherit field for release template inheritance by
    @mumoshu in #606
  * Use gopkg.in/yaml.v2 for Helmfile v0.x by @mumoshu in #609
  * build(deps): bump golang.org/x/term from 0.3.0 to 0.4.0 by
    @dependabot in #616
  * build(deps): bump gitpython from 3.1.27 to 3.1.30 in /docs by
    @dependabot in #618
  * Enhance tpl func test by @yxxhero in #619
  * feat: mark deprecated args and cmd for v1 by @yxxhero in #628
  * fix fetch does not work with kustomized releases by @xiaomudk
    in #624
  * Drop Helm v2 support by @xiaomudk in #613
  * Reset values flag by @kkoralsky in #602
* Fri Dec 23 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.149.0:
  New feature
  * Declare the use of --reuse-values in helmDefaults (#527)
  * Pass helmfile.yaml via stdin using -f - (#520)
  * The secrets field now accept go-getter URLs as well (#560)
  * Declare the use of Helm’s --post-render via Helmfile flags,
    helmfile.yaml helmDefaults and release fields (#510)
  * Support helm v3.10.3 (#579)
  What's Changed
  * Enhance make fmt to cover running gci for golangci-lint compat
    by @mumoshu in #515
  * Use log capturing helper in TestApply_hooks by @mumoshu in #516
  * Use the new log capturing helper in all remaining tests by
    @mumoshu in #517
  * declare "reuse values" control mode in helmDefaults by
    @kkoralsky in #527
  * Fix getArray function copy error by @xiaomudk in #533
  * Remove redundant metadata fields from test samples by
    @xiaomudk in #535
  * Allow helmfile statefile to passed by stdin by @xiaomudk in #520
  * Refactor integration tests by @yxxhero in #531
  * fix ghr badge by @yxxhero in #537
  * fix unit test by @yxxhero in #538
  * fix ghcr-badge in docs by @yxxhero in #539
  * rework dockerfiles by @jouve in #519
  * use dyff as yamldiff tool by @yxxhero in #542
  * fix go mod by @yxxhero in #543
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.1.1
    to 3.2.0 by @dependabot in #551
  * build(deps): bump github.com/variantdev/vals from 0.19.0 to
    0.20.0 by @dependabot in #552
  * rm embrawtest/myapp/foo.yaml.gotmpl by @yxxhero in #554
  * build(deps): bump github.com/Masterminds/sprig/v3 from 3.2.2
    to 3.2.3 by @dependabot in #556
  * typo: fix typo in cmd/apply.go by @yxxhero in #549
  * build(deps): bump go.uber.org/zap from 1.23.0 to 1.24.0
    by @dependabot in #557
  * build(deps): bump golang.org/x/term from 0.2.0 to 0.3.0
    by @dependabot in #562
  * Use go-getter with secrets as well by @itscaro in #560
  * Fix snapshot tests to pass regardless of helm version by
    @yxxhero in #572
  * Fix preapply hooks are not called on no diff when run apply
    subcommand by @xiaomudk in #522
  * build(deps): bump github.com/variantdev/vals from 0.20.0 to
    0.21.0 by @dependabot in #570
  * build(deps): bump github.com/go-test/deep from 1.0.8 to
    1.1.0 by @dependabot in #569
  * build(deps): bump k8s.io/apimachinery from 0.25.4 to
    0.26.0 by @dependabot in #568
  * Add documentation on go-getter cache by @itscaro in #566
  * Allow running images with users other than root by @pathob
    in #546
  * add xiaomudk as maintainer by @yxxhero in #504
  * Avoid --skip-refresh on local charts by @indrekj in #541
  * fea(#507): support assign --post-renderer flags ， helmDefaults
    config ， release config when use helm v3 by @tanguofu in #510
  * remove temporary dir as well by @itscaro in #563
  * build(deps): bump go.uber.org/multierr from 1.6.0 to 1.9.0 by
    @dependabot in #575
  * add post render integration test by @yxxhero in #576
  * clean: optimize post-render code by @yxxhero in #577
  * build(deps): bump helm.sh/helm/v3 from 3.10.2 to 3.10.3 by
    @dependabot in #578
  * bump helm to v3.10.3 by @yxxhero in #579
  * update postrenderer docs by @yxxhero in #580
* Tue Nov 15 2022 manfred.h@gmx.net
- Remove incorrectly added go_provides and go_nostrip macros
- Add definition for SOURCE_DATE_EPOCH to enable reproducible builds
* Tue Nov 15 2022 manfred.h@gmx.net
- Update to version 0.148.1:
  What's Changed
  * Introduce a new test helper for easier log snapshot testing by
    @mumoshu in #514
  * fix: helmfile template fails when selector matches a chart
    fetched with go-getter by @yxxhero in #499
- Update to version 0.148.0:
  What's Changed
  * fix: child process not exit when recive term signal by @yxxhero
    in #418
  * deps: build with go1.19 by @chenrui333 in #420
  * Update ci.yaml by @mumoshu in #422
  * fix helmfile version issue in docker image by @yxxhero in #427
  * Prevent excessive log in tests by @mumoshu in #424
  * Fix preapply hook behavior by @mumoshu in #423
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0 by
    @dependabot in #433
  * deps: update dockerfile dependencies by @chenrui333 in #421
  * feat: add helm-diff and kustomize in ci matrix by @yxxhero
    in #434
  * build(deps): bump helm.sh/helm/v3 from 3.10.0 to 3.10.1 by
    @dependabot in #436
  * build(deps): bump k8s.io/apimachinery from 0.25.2 to 0.25.3
    by @dependabot in #439
  * fix: issue path in test on windows by @yxxhero in #449
  * fix: fix deps args by @yxxhero in #446
  * fix helmfile diff error in window platform by @yxxhero in #451
  * move HELMFILE_UPGRADE_NOTICE_DISABLED into envvar file by
    @yxxhero in #441
  * Add --skip-refresh flag to the build command by @indrekj in #444
  * fix: needs logic in chart stage by @yxxhero in #458
  * fix typo by @yxxhero in #461
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to
    1.8.1 by @dependabot in #462
  * fix --debug flag by @yxxhero in #465
  * use curl instead of wget & update helm to 3.10.1 by @itscaro
    in #467
  * add basepath along with filepath into yaml comment by @itscaro
    in #460
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1
    by @dependabot in #470
  * Fix OCI example by @itscaro in #476
  * fix chart needs test issue by @yxxhero in #480
  * use fs.Getwd() to get working dir for sub helmfile by @itscaro
    in #471
  * Document git for windows env auto-prefix #481 by @strainovic
    in #487
  * fix oci:// chart by @itscaro in #477
  * Allow to override build date with SOURCE_DATE_EPOCH by
    @bmwiedemann in #486
  * Add subcommand init for checks and installs helmfile deps by
    @xiaomudk in #389
  * split run.sh to make run.sh be more clear. by @yxxhero in #485
  * remove hooks dir by @yxxhero in #484
  * fix: args parse issue by @yxxhero in #457
  * fix deps issues by @yxxhero in #492
  * test: add template anchors merge e2e test by @yxxhero in #494
  * feat: add go test total cover by @yxxhero in #495
  * Add --output-dir-template flag to the fetch command by
    @elchenberg in #456
  * build(deps): bump helm.sh/helm/v3 from 3.10.1 to 3.10.2 by
    @dependabot in #511
  * bump: helm to 3.10.2 by @yxxhero in #512
  * build(deps): bump k8s.io/apimachinery from 0.25.3 to 0.25.4 by
    @dependabot in #513
  * Add the ability to specify a lock file by @lassizci in #432
* Sun Oct 30 2022 manfred.h@gmx.net
- go1.19 is required for building.
* Sun Oct 30 2022 manfred.h@gmx.net
- Update to version 0.147.0:
  v0.147.0 is the first Helmfile version to officially support Helm
  3.10.0, along with several fixes and new features.
  Starting from helmfile v0.147.0, helmfile version will check for
  the latest version of Helmfile and print a tip if the current
  version is not the latest. To disable this behavior, set
  environment variable HELMFILE_UPGRADE_NOTICE_DISABLED to any
  non-empty value.
  What's Changed
  * build(deps): bump helm.sh/helm/v3 from 3.8.1 to 3.9.4 by
    @dependabot in #377
  * Update towards-1.0.md by @mumoshu in #378
  * build(deps): bump k8s.io/apimachinery from 0.24.4 to 0.25.1
    by @dependabot in #376
  * build(deps): bump helm.sh/helm/v3 from 3.9.4 to 3.10.0 by
    @dependabot in #387
  * build(deps): bump k8s.io/apimachinery from 0.25.1 to 0.25.2
    by @dependabot in #386
  * docs: fix best pratices guide link by @TartanLeGrand in #398
  * Fix incubator charts location in advanced-features.md by
    @duckty in #401
  * fix: docs typo by @stoned in #400
  * fix path issue in windows by @yxxhero in #385
  * fix: build command short description by @stoned in #403
  * imprv: convert hyphen included in repo name to underbar with
    gatherOCIUsernamePassword. by @mugioka in #406
  * Optimize cmd pkg by @yxxhero in #384
  * update helm-diff version to 3.5.0 by @yxxhero in #379
  * Update ci.yaml and use helm 3.10.0 by @yxxhero in #383
  * Use helm show chart to identify chart version by @felipecrs
    in #395
  * fix SetRetainValuesFiles issue by @yxxhero in #388
  * bump: upgrade gopkg.in/yaml.v2 to gopkg.in/yaml.v3 by
    @yxxhero in #396
  * docs: update docs order by @yxxhero in #407
  * feat: retrieve repository's username/password from environment
    by @kevinleturc in #415
  * feat: add more clear error message and Environment info for
    template by @yxxhero in #413
  * doc: update template funcs docs by @yxxhero in #414
  * fix README.md users.md to USERS.md by @yxxhero in #410
  * feat: optimize version output by @yxxhero in #412
  * feat: add reuse-values args for diff apply and sync by @yxxhero
    in #411
  * fix: helmfile deps issue with oci repo by @yxxhero in #419
* Wed Sep 28 2022 manfred.h@gmx.net
- Update to version 0.146.0:
  This minor release incorporates many new features and a few bug
  fixes, almost all thanks to 5 new contributors! Kudos to everyone
  who contributed code 🙏
  Also, we've been fixing a handful of regressions introduced via
  v0.145.0 in v0.145.x patch releases. For this release, the only
  regression we found and fixed was #370. Hopefully, this will be
  the most reliable release ever since v0.145.0!
  What's Changed:
  * Support helm-secrets v4.0.0 by @KqLLL in #360
  * use latest helm in github ci by @yxxhero in #367
  * feat: show live output from the Helm binary by @rodrigorfk
    in #286
  * remove flags.Parse in cobra by @yxxhero in #369
  * fix(oci): clean dead code by @jycamier in #290
  * added option for --no-hooks for helm diff and apply by
    @arpanadhikari in #279
  * chore: Tidy up a local var scopinng for maintainability by
    @mumoshu in #372
  * move interactive option to global by @yxxhero in #370
  * fix: add missing untar flag to pull chart from oci registry
    by @toVersus in #371
  * update CLI Ref by @yxxhero in #373
  * Add preapply hook by @Sajfer in #79
  * Fix not to ignore diff selector when it matched nothing by
    @mumoshu in #374
  * Bump chartify to v0.11.0 by @mumoshu in #375
* Thu Sep 15 2022 manfred.h@gmx.net
- Update to version 0.145.5:
  This patch release is mainly for fixing the default --skip-needs
  setting. If you had to add --skip-needs to every helmfile run
  since v0.145.0, this fixes that- you no longer need to explicitly
  set --skip-needs. To be clear, --skip-needs has been the default
  since v0.139.2. We just unintentionally broke it in v0.145.0!
  See #339 for more details. Thanks a lot for filing the detailed
  issue @strainovic, and thanks a lot for fixing the issue @yxxhero!
  * chore: update Jenkins's main helmfile repository in USERS by
    @lemeurherve in #320
  * fix ci error in issue.2118.yaml by @yxxhero in #319
  * Add Users information in Readme.md by @yxxhero in #317
  * build(deps): bump go.uber.org/zap from 1.22.0 to 1.23.0 by
    @dependabot in #322
  * Fix typos in docs by @dreglad in #329
  * Add --interactive option to sync, delete and destroy / Remove
  - -interactive from global options by @yxxhero in #328
  * use helmfile testdata by @yxxhero in #326
  * chore: remove 'OSS' from Jenkins name by @lemeurherve in #331
  * add subshell to USERS.md by @philmtd in #335
  * add NDR to USERS.md by @muffl0n in #336
  * feat: honor concurrency in withPreparedCharts by @stek29 in #345
  * feat: dont prepare on list by @stek29 in #346
  * docs: add docs for helmfile list by @stek29 in #350
  * build(deps): bump github.com/urfave/cli from 1.22.9 to 1.22.10
    by @dependabot in #351
  * build(deps): bump github.com/google/go-cmp from 0.5.8 to 0.5.9
    by @dependabot in #353
  * fixed: selector help msg style by @yxxhero in #348
  * update docs for CLI by @yxxhero in #356
  * Fix --skip-needs regression introduced in v0.145.0 by @yxxhero
    in #342
  * fix github ci matrix config by @yxxhero in #361
  * Fix incorrent exit code issue introduced in v0.145.0 by @yxxhero
    in #359
- Update to version 0.145.4:
  This patch release is mainly about fixing readDirEntries added
  in 0.145.3. @arkaitzj did a lot of awesome work along the way!
  We appreciate your contribution ❤️
  In addition to the fix, this release also covers fixes for a
  few diff-related flags that were not working since v0.145.0's
  move to cobra as the CLI library.
  * Fix for readDir selection, currently any template that uses
    readDir* functions seems to break by @arkaitzj in #297
  * Bring back --set flag to apply subcommand by @mjura in #298
  * fix: return diff output config value by @mikelorant in #303
  * fix: return diff context config value by @mikelorant in #301
  * Fix some multi-value flags to not accept comma-separated
    values by @yxxhero in #300
  * build(deps): bump k8s.io/apimachinery from 0.24.3 to 0.24.4
    by @dependabot in #306
  * Add logo as .png and .ai (Adobe Illustrator) files by
    @pathob in #263
  * Introduce Helmfile's own filesystem abstraction to correctly
    unit test some components by @arkaitzj in #307
  * fix typo for readme.md by @thenam153 in #312
* Wed Aug 24 2022 manfred.h@gmx.net
- autocomplete files have been removed; obsolete bash-completion
  and zsh-completion sub-packages older than this version.
* Wed Aug 24 2022 manfred.h@gmx.net
- Update to version 0.145.3:
  * Bump github.com/hashicorp/go-version from 1.4.0 to 1.6.0 by
    @dependabot in #183
  * fix doc link error and style error by @yxxhero in #217
  * fix(doc): add missing version field in the release template
    example by @lemeurherve in #228
  * update readme about image repo and fix link error by @yxxhero
    in #224
  * fix: use helm secrets view rather than helm secrets dec to
    decrypt by @philomory in #201
  * add Go lint by @yxxhero in #169
  * Include the working helmfile ver in the bug report by
    @mumoshu in #237
  * update Readmd.md by @yxxhero in #236
  * feat: bump chartify to v0.10.0 to support OCI registry for adhoc
    dependencies by @toVersus in #238
  * on canary build, version should show "0.0.0-dev" by @itscaro in
    [#162]
  * Add integration test for #238 with local docker registry as a
    OCI-based helm chart repo by @mumoshu in #239
  * chore: clean up snapshot test by @toVersus in #241
  * doc: getting start adds repositories configuration by @xiaomudk
    in #240
  * Use cobra by @yxxhero in #234
  * E2E helmfile-template testing with local chart repo server by
    @mumoshu in #245
  * correct --help cli arg regression by @jouve in #252
  * revert environment long option from --env to --environment by
    @jouve in #250
  * test: Add unit tests for ChartExport by @xiaomudk in #256
  * test: Add unit tests for ChartPull by @xiaomudk in #257
  * fix: OCI Url and Version parse error by @xiaomudk in #258
  * Implement readDirEntries method by @vasicvuk in #254
  * remove selector override in cmd/apply by @jouve in #266
  * update doccs/index.md about CLI ref by @yxxhero in #264
  * fix: needs error with context that includes slash by @sergeief
    in #268
  * Bump k8s.io/apimachinery from 0.23.4 to 0.24.3 by @dependabot
    in #230
  * Add flags about need for lint subcmd by @yxxhero in #273
  * fix go.mod by @yxxhero in #275
  * Refactor cobra flag default values for readability by @yxxhero
    in #274
  * build(deps): bump go.uber.org/zap from 1.21.0 to 1.22.0 by
    @dependabot in #280
  * Add file existence check for remote values by @kuzaxak in #284
  * Update ArchLinux installation instructions by @AnatolyRugalev
    in #282
  * Fix Inclusion of Releases for Other Environments by @dackroyd
    in #276
  * Cleanup pkg/config/config.go by @yxxhero in #287
  * update golang lint by @yxxhero in #288
  * Refactor 'images' workflow, include Ubuntu image to push by
    @pathob in #262
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to
    0.0.16 by @dependabot in #293
  * fix tag miss in docker build by @yxxhero in #294
* Tue Jul 26 2022 manfred.h@gmx.net
- Update to version 0.145.2:
  * The image publishing workflow should trigger on version tags
    by @mumoshu in #212
  * Fix helmfile-deps issue that it is unable to find the chartify
    output by @yxxhero in #214
- Update to version 0.145.1:
  * Bump github.com/stretchr/testify from 1.7.5 to 1.8.0 by
    @dependabot in #188
  * fix bug.yaml by @yxxhero in #198
  * test: use T.Setenv to set env vars in tests by @Juneezee in #189
  * Fix/invalid path on windows by @philomory in #200
  * fix within func issue by @yxxhero in #209
- Update to version 0.145.0:
  * Add an issue form for bug report by @mumoshu in #4
  * remove ioutil usage in all project by @yxxhero in #5
  * add unittest for formatters.go by @yxxhero in #9
  * mv captureStdout as public func by @yxxhero in #13
  * [test] update helm 3.8.0 to 3.8.1 by @itscaro in #16
  * add unittest for load_opts.go by @yxxhero in #11
  * bump go 1.18 & remove .circleci by @itscaro in #2
  * update args_test.go unittest by @yxxhero in #17
  * add unittest for RequiredEnv func by @yxxhero in #18
  * Update badge to reflect Github Action status by @itscaro in #19
  * [fix] unclosed file stream when creating temporary decrypted
    files by @itscaro in #20
  * [fix] bump go 1.18 & optional TAG definition in makefile by
    @itscaro in #21
  * Bump go-getter to 1.5.11 by @mumoshu in #25
  * [Dockerfile] only use image alpine for compilation, add sops
    & age to pre-built image, remove helm v2 image by @itscaro in #28
  * (fix) typo in state.go by @yxxhero in #32
  * fix output-dir issue by @yxxhero in #31
  * (fix) chartify process when chart path is absolute by @itscaro
    in #22
  * Fix non-existent custom temp dir by @itscaro in #37
  * Redact sensitive informations like password in chart url by
    @dol in #34
  * Fix helmfile deps not to remove entries for charts that are
    being chartified by @mumoshu in #23
  * feat: Auto-detect term for coloring helm-diff output by @mumoshu
    in #24
  * (test) update helm to 3.8.2 by @itscaro in #39
  * add unittest for constants.go by @yxxhero in #44
  * remove gotest deps by @yxxhero in #45
  * Update README.md by @mumoshu in #46
  * fix go lint warn by @yxxhero in #48
  * feat: Add openssh-client to images by @itscaro in #53
  * (feat) update helm to v3.8.2 in container images by @itscaro
    in #55
  * Create dependabot.yml by @itscaro in #54
  * add unittest for Exec by @yxxhero in #52
  * Add unittest for newExecutionID by @yxxhero in #62
  * add unittest for ValidateConfig by @yxxhero in #67
  * add unittest for context.go by @yxxhero in #68
  * remove temp_rand and use k8s.io/apimachinery/pkg/util/rand
    by @yxxhero in #69
  * add unittest for error.go in pkg/app by @yxxhero in #71
  * Bump github.com/stretchr/testify from 1.7.0 to 1.7.1 by
    @dependabot in #56
  * Bump github.com/go-test/deep from 1.0.7 to 1.0.8 by
    @dependabot in #60
  * Bump github.com/spf13/cobra from 1.3.0 to 1.4.0 by
    @dependabot in #59
  * Bump github.com/google/go-cmp from 0.5.7 to 0.5.8 by
    @dependabot in #93
  * Bump github.com/hashicorp/go-version from 1.2.1 to 1.4.0
    by @dependabot in #94
  * update doc for template func by @yxxhero in #74
  * [#80] README, update release tag url by @yjqg6666 in #81
  * chore: bump variantdev/vals to support remote secret
    tfstateremote by @carnei-ro in #76
  * [feat] add execEnvs by @yxxhero in #95
  * Bump go.uber.org/zap from 1.19.0 to 1.21.0 by @dependabot
    in #87
  * fix old URLs in docs and fix Dockerfile by @itscaro in #84
  * Bump github.com/urfave/cli from 1.22.5 to 1.22.9 by
    @dependabot in #96
  * Bump github.com/hashicorp/go-getter from 1.5.11 to 1.6.0 by
    @dependabot in #103
  * rename execEnvs to envExec by @yxxhero in #97
  * Rename module to github.com/helmfile/helmfile by @austince
    in #101
  * build image on tag by @itscaro in #40
  * Bump github.com/hashicorp/go-getter from 1.6.0 to 1.6.1 by
    @dependabot in #106
  * update envExec docs by @yxxhero in #104
  * add helm 3.9 to tests by @itscaro in #85
  * fix intergration test for argo-cd form master to main branch
    by @yxxhero in #118
  * feat: allow --validate on sync command by @chubchubsancho in #88
  * remove unused comments by @yxxhero in #112
  * Update sops version on dockerfile by @rodrigodc07 in #123
  * Update Helm diff plugin to version 3.5.0 in Dockerfile by
    @philippeckel in #122
  * Bump github.com/imdario/mergo from 0.3.12 to 0.3.13 by
    @dependabot in #114
  * add e2e tmpl test by @yxxhero in #99
  * reconstruct main function by @yxxhero in #83
  * little code optimize by @yxxhero in #130
  * Adds feature to fetch release values and secret values from
    remote by @dol in #47
  * introduce DISABLE_INSECURE_FEATURES to disable insecure
    executions by @itscaro in #1
  * chore(state): Append Api Versions flags to helm-diff by
    @semoac in #107
  * fix ci issue by @yxxhero in #131
  * Add yxxhero as a maintainer by @mumoshu in #132
  * Enhance the bug report form by @mumoshu in #134
  * Create SECURITY.md by @mumoshu in #135
  * Minor documentation fixes by @stoned in #138
  * Move repos subcommand to a dedicated source file by @yxxhero
    in #137
  * Add proposals about two breaking changes before we cut Helmfile
    1.0 by @mumoshu in #136
  * Fix deprecated chart in Getting Started by @ogugu9 in #140
  * proposal: Drop --args in Helmfile 1.0 by @mumoshu in #144
  * Move diff charts template subcommand to a dedicated source
    file by @yxxhero in #139
  * Bump module Go version to 1.18 by @mumoshu in #150
  * Release automation and release build testing by @mumoshu in #151
  * Bump github.com/stretchr/testify from 1.7.1 to 1.7.2 by
    @dependabot in #141
  * Bump github.com/variantdev/vals from 0.16.2 to 0.17.1 by
    @dependabot in #152
  * move all subcommand to sigle file by @yxxhero in #153
  * Bump github.com/variantdev/vals from 0.17.1 to 0.18.0 by
    @dependabot in #158
  * Bump github.com/hashicorp/go-getter from 1.6.1 to 1.6.2 by
    @dependabot in #159
  * feat(dockerfile): update helm to 3.9.0 by @Jasstkn in #163
  * docker build test on ci by @yxxhero in #164
  * Make a few helmfile sub-commands consistently support
    needs-related flags by @mumoshu in #78
  * Bump github.com/stretchr/testify from 1.7.2 to 1.7.3 by
    @dependabot in #172
  * fix ci test error by @yxxhero in #167
  * update Readme.md by @yxxhero in #170
  * Fix typo in README by @kobtea in #177
  * Bump github.com/stretchr/testify from 1.7.3 to 1.7.4 by
    @dependabot in #176
  * Update alpine base image to 3.16 by @jduepmeier in #179
  * Bump github.com/stretchr/testify from 1.7.4 to 1.7.5 by
    @dependabot in #180
  * add unittest for text_renderer.go by @yxxhero in #168
  * Bump github.com/spf13/cobra from 1.4.0 to 1.5.0 by
    @dependabot in #175
* Fri Apr  8 2022 Manfred Hollstein <manfred.h@gmx.net>
- v0.144.0:
  * Update README.md by @qb-abdul in #2105
  * Add .StateValues as alias of .Values in EnvironmentTemplateData
    by @itscaro in #2056
  * Add template function isFile by @itscaro in #2045
  * Enhance support for kube-version and api-versions by @mumoshu
    in #2121
* Sat Mar 19 2022 Manfred Hollstein <manfred.h@gmx.net>
- v0.143.1:
  * Add --skip-tests to helmfile template command by @drivelikebrazil
    in #2057
  * Fix context of the ReadDir templating function by @nlueb in #2058
  * Fix readdir regression while merging by @mumoshu in #2061
  * feat: Add --suppress option for diff and apply commands by
    @sjentzsch in #2077
  * enable get() to be used with alias $.StateValues by @itscaro
    in #2081
  * Use os.UserCacheDir()/helmfile to store downloaded artifacts
    instead of relative .helmfile directory by @itscaro in #2022
  * Fix various golangci-lint errors by @Sajfer in #2059
  * add integration tests for helm v3.8.0 by @itscaro in #2085
  * Update USERS.md by @yohanb in #2089
  * Allow more characters in label selectors by @Sajfer in #2064
  * Make release template to work on needs by @mumoshu in #2099
  * Stop panic when deduplicating releases by @Sajfer in #2067
  * Bump chartify to v0.9.2 by @mumoshu in #2102
* Sun Jan 23 2022 Manfred Hollstein <manfred.h@gmx.net>
- v0.143.0:
  * (HEAD, tag: v0.143.0) Fix panic on normalizing path containing .. (#2042)
  * add cleanup to write-values & lint to harmonise this flag (#2021)
  * Correct enabled property in helmfile list (#1921)
  * Add readDir as a templating function (#1934)
  * Set postsync and cleanup error (#2009)
  * Bump sprig library to v3.2.1 (#1880)
  * Allow users other than root to use helm plugins (#1766)
  * Added example ArgoCD + helmfile deployment (#1882)
  * Update README.md
  * Bump helm-diff to version 3.3.1 (#2041)
  * feat: Option to pass kubeVersion to helm template (#2002)
  * support apple silicon builds (#2032)
  * Bumped go-getter to v1.5.9 (#1982)
  * Fix capitalization of disableOpenAPIValidation config in README (#2003)
  * bump to go 1.17.3 with alpine 3.13 (#2024)
  * upgrade vals allowing for the use of the AzureRM terraform backend (#2029)
  * Add support for --insecure-skip-tls-verify flag on helm repo add command (#1990)
  * feat: Add go-getter support to load base helmfiles (#1998)
  * Do fail on a possible typo in needs entries (#2026)
  * Fix typo in README (#2006)
* Tue Nov  9 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.142.0:
  * Add support for transitive dependencies (needs). by @pjotre86 in #1983
  * Add documentation for needs parameterization. by @pjotre86 in #1987
  * Process feedback for pr 1983 by @pjotre86 in #1992
  * Make .Environment values available in .gotmpl files. by @pjotre86 in #2000
* Sat Oct 16 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.141.0:
  * 9a0ce53 (HEAD, tag: v0.141.0) Support Helm 3.7.0's reworked
    OCI support (#1970)
* Fri Sep 17 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.140.1:
  * 787e6c8 (HEAD, tag: v0.140.1) ubuntu docker based image for
    helmfile (#1863)
  * 724b4b3 readme: fix wrong paths for environments on conf
    example (#1885)
  * 2792ef7 bug: write-values deletes provided --values files.
    (#1905)
  * f57b510 Fix json patches and strategic patches to do work
    when there was only one resource in the targeted chart/directory
    (#1962)
  * 7845ccc Stop integration test for Helm 2.17.0 (#1961)
  * e1cabc8 Add support for --validate on chartify (#1960)
  * 0f91f2c Add IKEA to users. (#1925)
  * 8594944 Update writing-helmfile.md (#1937)
  * ae438c8 Add more examples for remote env value files (#1938)
  * ad2f8e8 Add debian docker image, drop helm2, upgrade packages.
    (#1956)
* Mon Aug 16 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.140.0: The following two changes were not included in the last
  snapshot release:
  * ccd81de (HEAD, tag: v0.140.0) Set longer no_output_timeout for
    release
  * 46b17e2 feat: pass-credentials to repo (#1899)
* Fri Jul 23 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.140.0:
  * d8247e6 (HEAD, tag: v0.140.0)
    Update writing-helmfile.md: fix typos (#1892)
* Fri Jun 11 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.139.9:
  * c623730 (HEAD, tag: v0.139.9)
    Bump golang.org/x/crypto (#1877)
- v0.139.8:
  * 72e7160 (HEAD, tag: v0.139.8)
    Fix chartify regression of missing chart dependencies (#1869)
  * 0d4adfe Document hooks events expressions (#1870)
* Tue May 25 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.139.7:
  * 1a109f7 (HEAD, tag: v0.139.7)
    Fix chartify inability to disable chart dependency (#1861)
  * 97bab23 Fix --skip-cleanup to work with chartify (#1860)
  * c881544 Update README.md
  * 92ba347 Add --skip-diff-on-install to helmfile diff (#1841)
- v0.139.6:
  * f502a0a (HEAD, tag: v0.139.6)
    fix: Do not fail on deps when chart is fetched by go-getter (#1852)
- v0.139.5:
  * 7724160 (HEAD, tag: v0.139.5)
    Fix Helmfile swallowing secrets decryption errors (#1849)
- v0.139.4:
  * f38958d (HEAD, tag: v0.139.4)
    Fix cache path issue on Windows (#1846)
- v0.139.3:
  * 212e6ac (HEAD, tag: v0.139.3)
    Fix helmfile-lint not to stop on fisrt error (#1836)
* Sun May  9 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.139.2
  This release fixes a breaking change introduced in v0.139.0.
  * efa404e (HEAD, tag: v0.139.2)
    Make --skip-needs=true the default option (#1835)
- v0.139.1
  This release include the fix for a regression introduced in
  v0.139.0, and additional fix for kubecontext usage in templates
  and --output-dir, and also the newer aws-sdk-go for AWS SSO
  support. You should always use v0.139.1 rather than v0.139.0.
  * 794ab9f (HEAD, tag: v0.139.1)
    Fix lint and status not to fail with selector and needs (#1834)
  * 48bd5c0 Update go.sum for successful build
  * e39a0b3 bump Go to 1.16.3 and cover helm 3.5.4 (#1825)
  * 5895410 fix kubeContext does not globally defaulting its value
    (#1829)
  * cb7fa6b Bump vals to 0.14.0 (#1832)
  * 44fb68b Use the incubator chart repo instead of chartcenter
    (#1833)
* Fri May  7 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.139.0
  This release includes a lot of bug fixes for forceNamespace,
  jsonPatches, strategicMergePatches, needs, kustomize integration,
  chartify, and the use of kubeContext in templates. If you use any
  of these features, upgrading to 1.139.x is highly recommended.
  This is a minor version bump because we had a bug fix that
  resulted in breaking some existing behavior. See #1831.
  CAUTION: Your pipeline may start failing due to a fixed bug. See
  [#1831] and add --skip-needs to your helmfile command if you'd like
  to opt-in to preserve the existing behaviour.
  * ded0f10 (HEAD, tag: v0.139.0)
    Fix filepath handling on Windows (#1754)
  * 08db073 Fix broken selector and DAG calculation logic after
  - -{include,skip}-needs addition with correct Release IDs (#1823)
  * de8644a Fix --selector results to correctly deduplicate releases
    (#1822)
  * f28ad5a Fix defaulting and overriding kubeContext (#1814)
  * 77ee239 Lock helm plugin versions in Dockerfile (#1821)
  * d9e1575 Add documentation about re-using the environment state
    from parent in sub-helmfile (#1808)
  * dabd7ad Fix repo sync to work on repos duplicated between helm
    v2 and v3 (#1816)
  * 204f78c Fix --set and --set-file flags are not passed to chartify
    (#1803)
  * 59b91a4 Fix adhoc dependencies not working with remote chart
    (#1802)
  * 5a3bd7d Fix destory, delete, and test to work with chartify on
    local chart with dependencies that are not yet downloaded (#1801)
  * ce6a621 Bump chartify to 0.8.3 to fix it not to break when two
    or more releases sharing the same chart and the namespace, but
    kubeContext (#1799)
  * 20f6c68 Fix code format
  * 3367822 feat: Move chartify logs to Debug (#1794)
  * 8702639 fix: spec.KubeContext does not fallback to
    HelmDefaults.KubeContext (#1789)
  * 41cbc25 fix: can't evaluate field KubeContext in type
    state.releaseTemplateDataRelease (#1797)
  * 83189db Enable helmfile-diff to pass the output format to
    helm-diff (#1784)
  * 28ade19 Bump chartify to 0.8.2 (#1793)
  * 378ae4a Fix typo (#1788)
  * 30e0356 Bump chartify to 0.8.1 (#1787)
  * eabda4c Fix delete on release of uninstalling status (#1786)
  * 5617b59 Add test for helmfile-destroy with selector (#1785)
  * 5d43b30 Add --{include,skip}-needs to various helmfile commands
    (#1772)
  * d6db4b5 Added The Hyve to USERS.md (#1779)
  * 368dd13 Fix destroy not reversing the order of releases (#1777)
  * ae942c5 Fix --skip-crds not working with chartify (#1774)
  * a111e89 Add --skip-crds to helmfile sync and helmfile apply (#1771)
  * 589b26a Fix some hook log not honoring log level (#1769)
  * 1d7608f Fix helmfile repos to not fail with forceNamespace
  * efad266 Add documentation about adhoc chart dependencies
  * 81b04fc Add support for adhoc dependency to local chart
  * 74cd2bc Enable helmfile-deps to limit helm-dep-up by selector (#1764)
  * 2ff06a8 Fix chartify to take --include-crds into account (#1761)
  * d703e17 Fix chartify not to fail on a chart with dependencies (#1759)
  * 3bfcc1e Add support for kustomize v4 (#1758)
  * c65bdff Respect release filter in lint and status (#1672)
  * f614e8b feat: Helmfile renders *.yaml.gotmpl in a K8s
    manifests/kustomization directory (#1745)
  * 85accf7 Add helm-secrets-encrypted values template file (#1701)
  * a161796 feat: Allow overriding chart via flag (#1751)
  * 261367e Add kubectl hooks for applying file(s) or kustomize (#1736)
  * 5cd0afc Add documentation about helmfile-fetch and StateValues
    alias (#1746)
  * 1748cbf Add .StateValues as alias of .Values in
    releaseTemplateDataRelease (#1744)
  * 200cae2 feat: --show-secrets on diff and apply commands (#1749)
  * b1b7831 feat: make --kube-context override helmDefaults (#1673)
  * 53c6d2f Add helmfile-fetch command to downloading and generating
    charts (#1734)
  * faa7496 Fix helmfile-template not writing to stdout (#1737)
  * 28cf300 Add support for kubeContext in environments (#1675)
  * e9d1c85 feat: change to helmfile template so it respects logging
    levels (#1691)
  * aafe74a Fix/secrets ordering (#1726)
  * db9d31a test: fix DecryptSecret output
  * 4a9d753 feat: make integration/vagrant
  * 4efaa65 test: return all tests
  * 59f4043 fix: fixed secrets decryption failed issue
  * d04cd1b test: fix "Ensure helmfile fails when no helm-secrets is
    installed" test
  * 781c4e9 test: fix "Ensure helmfile fails when no helm-secrets is
    installed" test
  * 0c9934c test: ensure bash -eo pipefail (as in circleci)
  * 2983f5c test: fix vault provisioning code
  * 7610d8d test: add secrets integration tests
  * 5cd853b test: add vault and sops for integration secret testing
  * f1c0787 ci: simplify integration tests ci code for helm2
  * d1a2435 ci: simplify integration tests ci code
  * 45b8eb6 test: fix helm2 integration tests
  * 17a969c ci: verify new integration tests
  * 4f02196 test: reusable integration test
  * 85f19b6 fix: gitignore *.lock
  * 42138d8 test: vagrant for integration tests
  * 2ef09d4 test: sync HELM_VERSION and KUSTOMIZE_VERSION for tests
  * 9b2a770 feat(Dockerfile): pin helm-secrets version
  * 6085730 fix(Makefile): static-linux mod
  * 94a8658 feat(Dockerfile): bump helm version
  * 2618cfb Enable --wait-for-jobs flag introduced in helm 3.5 (#1715)
  * fcf9a72 Improve error message on deps resolution error (#1727)
  * 5ce755e Add chart & version to list cmd output (#1731)
  * b7d6639 (fix) remove usage of charts.yaml in error message (#1732)
  * 9575995 Add William Hill to USERS.md (#1735)
* Tue Mar  9 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.138.7
  * 8ed8a9e (HEAD, tag: v0.138.7)
    allow to access oci repos without auth (#1711)
  * 14a83e7 Update reference for helm-secrets to latest maintained
    fork (#1676)
  * bf9f36b refactor: simplify pull channel from #1706 (#1707)
  * 3215eaf panic with clear message (#1709)
  * 927bd30 Update README.md to show current CLI Output (#1712)
- v0.138.6
  * 247ae91 (HEAD, tag: v0.138.6)
    Disable darwin/386 build to avoid release failure
- v0.138.5
  * 97f0e59: Update README.md (#1677)
* Sat Feb 13 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.138.4
  * f24b61f (HEAD, tag: v0.138.4)
    Fix error on concurrent go-getter on same URL (#1669)
- v0.138.3
  * 257c1f6 (HEAD, tag: v0.138.3)
    Fix OCI support (#1667)
  * 4e1ecb5 Bump variantdev/vals to 0.13.0 (#1666)
- v0.138.2
  * ad5fba5 (HEAD, tag: v0.138.2)
    Bump Helm to v3.5.0. (#1656)
  * 0ad62b5 docs: update helm command name (#1635)
  * 8487970 fix: dont sent RegistryLogin password via args (#1662)
* Sat Jan 30 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.138.1: fix: fixed up OCI repos so they support paths and URLs
  that differ fr…
  * 8212b63 (HEAD, tag: v0.138.1)
  fix: fixed up OCI repos so they support paths and URLs that differ
  from chart names contained there (#1661)
- v0.138.0: feat: added in oci repository flag and added helm
  methods to pull and…
  * 2a71640 (HEAD, tag: v0.138.0)
  feat: added in oci repository flag and added helm methods to pull
  and export charts (#1629)
* Wed Jan 13 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.137.0: docs: fix typo (#1645)
  * 33880da (HEAD, tag: v0.137.0)
    docs: fix typo (#1645)
  * 87fcd83 Fix typo "verion" (#1641)
  * 600721c docs(readme): fix typo (#1633)
  * f7a1d09 Bump variantdev/vals to 0.12.0 (#1644)
* Sun Jan  3 2021 Manfred Hollstein <manfred.h@gmx.net>
- v0.136.0
  * e5d982e (HEAD, tag: v0.136.0)
    Fix "No valid platforms to build for" build error on release
  * c815d01 Bump helm versions in Dockerfile to deal with stable and
    incubator repositories change
  * 9569d73 Bump helm versions in CI to deal with stable and incubator
    repositories change
  * dd5bc46 Include kustomize binary in helm3-based Docker image (#1626)
  * fc3567d Adding documentation for PR #6819 (#1623)
  * 9b64d65 feat: Stabilize helmfile-diff output (#1622)
  * 54eb73b Use ghodss/yaml for yaml marshaling & unmarshaling in
    template (#1556)
  * 4c0987a Don't append --tiller-namespace flag when running helm3 (#1594)
  * 0637973 fix: allow helmfiles to be corrected marshalled to YAML
    so they can be manipulated by other programs (#1604)
  * 3690bde Add documentation on how to use the docker image (#1607)
  * b92ff2b Fix selector syntax example (#1614)
  * afe82f6 chore: suppress empty values on serializing several helmfile
    values (#1616)
  * 1c7b872 Stabilize helmfile-diff output (#1619)
  * 28e7ebb fix: support arm64 images (#1612)
  * 1ef9b29 Improve handling of releases being newly installed by
    helmfile-apply (#1618)
* Mon Nov 23 2020 Manfred Hollstein <manfred.h@gmx.net>
- Add bash and zsh completion sub-packages
* Thu Nov 19 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.135.0: Add support for Kustomize Transformers (#1592)
  * b910591 (HEAD, tag: v0.135.0)
    Add support for Kustomize Transformers (#1592)
  * d807510 Enable shell completion (#1559)
  * 4e48521 Fix the logic of helmfile deps and add tests. (#1588)
  * b0e0429 Fix incorrect help text of some CLI options. (#1587)
  * f877de7 Fix openSUSE repo URL. (#1584)
  * 655d593 Mention about helmBinary in readme (#1590)
- v0.134.1: Fix `helmfile template --include-crds` not to break with
  `chartify` (…
  * f6bf885 (HEAD, tag: v0.134.1)
    Fix helmfile template --include-crds not to break with chartify (#1583)
  * 2857382 fix: support arm binaries (#1580)
  * 972667f Mention openSUSE packages for helmfile (#1581)
  * 3c88145 Update readme stable/incubator URLs (#1582)
* Tue Nov 10 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.134.0: Bump dependencies (#1573)
  * 709913b (HEAD, tag: v0.134.0)
    Bump dependencies (#1573)
  * 88884b6 feat: helmfile template --skip-cleanup (#1570)
  * 5a15b65 feat: Add helmfile apply --skip-cleanup (#1571)
  * 3899680 feat: Add helmfile test --logs (#1569)
- v0.133.0: feat: Add `helmfile template --include-crds` (#1568)
  * 6b86408 (HEAD, tag: v0.133.0)
    feat: Add helmfile template --include-crds (#1568)
* Sun Nov  8 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.132.3: Fix redundant helm-dep-build and prepare hook regression
  (#1566)
  * bdbaa00 (HEAD, tag: v0.132.3) Fix redundant helm-dep-build
    and prepare hook regression (#1566)
- v0.132.2: Fix `helmfile --selector x=y template` with `needs`
  (#1564)
  * 87e86dc (HEAD, tag: v0.132.2)
    Fix helmfile --selector x=y template with needs (#1564)
  * 995b201 mention Arch Linux support (#1549)
* Tue Oct 27 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.132.1: Disable dependency update while running helm-x/chartify
  in more cases…
  * 0663831 (HEAD, tag: v0.132.1)
    Disable dependency update while running helm-x/chartify in more
    cases (#1548)
  * afb2653 fix: printing error to stdout together with templated
    resources (#1550)
* Thu Oct 22 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.132.0: Minor README improvement (#1543)
  * 9ec4a85 (HEAD, tag: v0.132.0)
    Minor README improvement (#1543)
  * 4d86879 Improve capitalization and formats of README.md. (#1545)
  * 1aca099 feat: Upgrade to kubectl version supported by latest
    stable release and upgrade helm3 to 3.3.4 (#1498)
  * f5d0988 Retain the option helm repo add --force-update when Helm
    is v3.3.4 or above. (#1546)
* Sun Oct 18 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.131.0: Bump chartify to 0.4.4 (#1540)
  * 080080f (HEAD, tag: v0.131.0)
    Bump chartify to 0.4.4 (#1540)
  * cd4afc3 Remove duplicated logs from helm.exec. (#1538)
  * 8f86697 Support for azure acr helm repositories (#1526)
* Sun Oct 18 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.130.3: Bump vals (#1537)
  * 563fce4 (HEAD, tag: v0.130.3)
    Bump vals (#1537)
  * b287101 Update USERS.md (#1535)
- v0.130.2: Fix concurrent-map-iteration-and-write errors while running release h…
  * ab9fb2c (HEAD, tag: v0.130.2)
    Fix concurrent-map-iteration-and-write errors while running
    release hooks (#1534)
  * c170b5a Minor tweaks for helmfile write-values (#1533)
  * d9286ed Fix intermittent failures while building deps on local
    chart (#1532)
  * 3018e82 Fix multiple --set in --args messed up in helmfile
    template (#1529)
  * 34acf14 Bump chartify to v0.4.3 (#1528)
  * 5d8eba9 Append --force-update for specific helm versions. (#1494)
  * b284b7b chore: add SettleMint to the USERS list (#1516)
  * b293ac1 Fix typo (#1523)
  * 8d9d635 Clarify namespace prefix in needs (#1500)
* Tue Oct  6 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.130.1: Fix: forceNamespace needs shouldRun is true (#1510)
  * 954673d (HEAD, tag: v0.130.1)
    Fix: forceNamespace needs shouldRun is true (#1510)
* Tue Sep 29 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.130.0: Add support for ChartCenter (#1492)
  * 942b9a6 (HEAD, tag: v0.130.0)
    Add support for ChartCenter (#1492)
* Mon Sep 21 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.129.4: Enable `helmfile test` testing only enabled and selected
  releases (#1…
  * b176408 (HEAD, tag: v0.129.4)
    Enable helmfile test testing only enabled and selected releases (#1486)
  * ff81b2f Enable release hook template to access .Values (#1485)
  * 8db03f9 Drop duplicated entry in extra functions list from readme (#1490)
  * 988c218 Support the latest Helm (>=v3.3.2) and bump the Helm version
    in Docker image. (#1488)
* Tue Sep 15 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.129.3: Treat selector with multiple conditions an AND (#1478)
  * 028bcc5 (HEAD, tag: v0.129.3)
    Treat selector with multiple conditions an AND (#1478)
- v0.129.2: Bump vals (#1475)
  * 5dd65e8 (HEAD, tag: v0.129.2)
    Bump vals (#1475)
- v0.129.1: Add tailormed to users (#1467)
  * 134d5be (HEAD, tag: v0.129.1)
    Add tailormed to users (#1467)
  * 87d04f0 Append KubeContext to temporary directory path (#1471)
  * 2d7c8e7 Update README.md (#1472)
- v0.129.0: Add experimental write-values command for writing values files only (…
  * 0fad9f0 (HEAD, tag: v0.129.0)
    Add experimental write-values command for writing values files only (#1469)
- v0.128.2: Re-add Release.Namespace in release values.yaml templates (#1466)
  * 832dcf4 (HEAD, tag: v0.128.2)
    Re-add Release.Namespace in release values.yaml templates (#1466)
  * 1d2c8b8 Adding hellofresh as a helmfile user (#1465)
- v0.128.1: Fix `index out of range [1] with length 1` error on env2map (#1463)
  * 0482ba3 (HEAD, tag: v0.128.1)
    Fix index out of range [1] with length 1 error on env2map (#1463)
- v0.128.0: Bump sprig to v3.1.0 and mergo 3.11 (#1456)
  * 9d2c0d4 (HEAD, tag: v0.128.0)
    Bump sprig to v3.1.0 and mergo 3.11 (#1456)
- v0.127.0: Bump sprig to v3 (#1452)
  * efd26f2 (HEAD, tag: v0.127.0)
    Bump sprig to v3 (#1452)
- v0.126.2: Fix wrong deletion order (#1451)
  * 5f1698d (HEAD, tag: v0.126.2)
    Fix wrong deletion order (#1451)
  * 2ecf578 Revise GitOps doc a bit
- v0.126.1: Fix test flake for `commonLabels` (#1449)
  * 3e6542e (HEAD, tag: v0.126.1)
    Fix test flake for commonLabels (#1449)
  * d3daea3 Fix panic on hook since v0.126.0 (#1448)
  * 19d7942 Add experimental "forceNamespace" in helmfile.yaml (#1444)
* Mon Aug 31 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.126.0: Fix build error after `helmfile build --embed-values` addition
  * cd0ecc5 (HEAD, tag: v0.126.0)
    Fix build error after helmfile build --embed-values addition
  * dc6c59d Print command output in line (#1354)
  * 0fc0869 feat: helmfile build --embed-values to embed release
    values and secrets into the output (#1436)
  * 5ca7ce1 feat: common labels for all releases in a helmfile (#1415)
  * 6b4b76e HELMFILE_ENVIRONMENT variable (#1425)
  * 7b11ce8 feat: Allow .Release.Name to be used in gotmpl values
    templates (#1424)
* Mon Aug 31 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.125.9: Merge pull request #1442 from roboll/fix-duplicate-with-kubectx-per-r…
  * c575587 (HEAD, tag: v0.125.9)
    Merge pull request #1442 from roboll/fix-duplicate-with-kubectx-per-release
  * f2dfa7c Fix kubeContext not taken into account for release uniqueness
  * 41cd1fe Fix race while running helm dep build on local chart (#1439)
  * 94e01b7 Bump chartify to 0.4.2 (#1437)
  * 85e7798 Update to the latest version of helm-diff plugin (#1430)
  * b42e847 Fix race while running helm dep build on local chart
- v0.125.8: Fix regression in helmfile deps (#1431)
  * 14e2b9e (HEAD, tag: v0.125.8)
    Fix regression in helmfile deps (#1431)
  * 90a4122 fix: panic when using helm v3.3 (#1427) (#1428)
* Mon Aug 17 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.125.7: Fix regression installing raw K8s manifests (#1417)
  * a9aa7af (HEAD, tag: v0.125.7)
    Fix regression installing raw K8s manifests (#1417)
  * 738409e Fix regression for helmfile template with helm v2 since
    v0.125.4 (#1416)
- v0.125.6: Revert filtering on repositories to be updated (#1412)
  * ec87a39 (HEAD, tag: v0.125.6)
    Revert filtering on repositories to be updated (#1412)
  * ab1c118 Bump chartify to v0.4.0 (#1409)
  * c8c444d Add test case (#1410)
- v0.125.5: Fix chart fetched by go-getter not to fail due to missing
  dependencies
  * 9a03d79 (HEAD, tag: v0.125.5)
    Fix chart fetched by go-getter not to fail due to missing
    dependencies (#1408)
- v0.125.4: Fix race on/sometimes missing postsync and cleanup hooks
  (#1407)
  * 0ef7e65 (HEAD, tag: v0.125.4)
    Fix race on/sometimes missing postsync and cleanup hooks (#1407)
  * 61b61d3 Fix helmfile template with Helm 3 ignoring chart version
    (#1406)
  * 2710cb3 Fix go-getter URL in chart to actually work (#1405)
  * 4d7fcd8 doc: ArgoCD integration (#1402)
* Thu Aug  6 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.125.3: Fix various issues in chart preparation (#1400)
  * b85243a (HEAD, tag: v0.125.3)
    Fix various issues in chart preparation (#1400)
  * 53c3fe9 Add support for selector on helmfile template (#1399)
- v0.125.2
  * 2ce57ba (HEAD, tag: v0.125.2)
    Handle --disable-openapi-validation parameter in helm upgrade (#1396)
  * cc9b7f3 Fix regression on template failing due to duplicate fetch
    target (#1395)
- v0.125.1: Fix `helmfile lint` failure when `installed: false` (#1391)
  * 85a2024 (HEAD, tag: v0.125.1)
    Fix helmfile lint failure when installed: false (#1391)
  * 8757308 Fix false-positive duplicate release with kubeContext (#1390)
  * 4fb47a8 Add version sub-command (#1389)
  * 9cffef5 Update documentation to mention Renovate integration (#1387)
  * b485793 Fix lint to not fail for duplicate release names across
    ns (#1388)
  * 1e260e4 Fix and enhancement to repository update (#1383)
* Fri Jul 24 2020 Manfred Hollstein <manfred.h@gmx.net>
- v0.125.0: Add pre/postuninstall hooks (#1375)
  * ee8ea50 (HEAD, tag: v0.125.0)
    Add pre/postuninstall hooks (#1375)
  * b5830a3 Add ability to use go-getter for fetching remote manifests
    directory as chart (#1374)
- v0.124.0: Add disableValidation and disableOpenAPIValidation per
  release (#1373)
  * 4fde6e1 (HEAD, tag: v0.124.0) Add disableValidation and
    disableOpenAPIValidation per release (#1373)
  * a5e790c Add Jenkins OSS to the list of users (#1372)
  * 1e956ae Fix list failure when patches are used (#1371)
- v0.123.0: Bump variantdev/vals for better Variant KV v2 support
  (#1367)
  * 1671b8b (HEAD, tag: v0.123.0)
    Bump variantdev/vals for better Variant KV v2 support (#1367)
- v0.122.2: Bump chartify to 0.3.11 (#1366)
  * 608ba19 (HEAD, tag: v0.122.2)
    Bump chartify to 0.3.11 (#1366)
  * daf7d3b fix the issue in the documentation (#1364)
* Fri Jul 17 2020 Manfred Hollstein <manfred.h@gmx.net>
- Install program using "make install" to ensure it knows its version
  number.
* Fri Jul 17 2020 Manfred Hollstein <manfred.h@gmx.net>
- Add _service* files to automate source and vendor tarball retrieval
* Fri Jul 17 2020 Manfred Hollstein <manfred.h@gmx.net>
- Replace hard-coded version numbers with %%{version}
* Fri Jul 17 2020 Manfred Hollstein <manfred.h@gmx.net>
- Initial revision of v0.121 from gitlab.
